# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_endpoint": "accessEndpoint",
    "access_policies": "accessPolicies",
    "access_policy_object_ids": "accessPolicyObjectIds",
    "access_tier": "accessTier",
    "account_encryption_source": "accountEncryptionSource",
    "account_endpoint": "accountEndpoint",
    "account_kind": "accountKind",
    "account_name": "accountName",
    "account_replication_type": "accountReplicationType",
    "account_tier": "accountTier",
    "account_type": "accountType",
    "action_storage_queue": "actionStorageQueue",
    "action_web": "actionWeb",
    "active_active": "activeActive",
    "active_directory": "activeDirectory",
    "add_on_features": "addOnFeatures",
    "additional_capabilities": "additionalCapabilities",
    "additional_locations": "additionalLocations",
    "additional_properties": "additionalProperties",
    "addon_profile": "addonProfile",
    "address_prefix": "addressPrefix",
    "address_spaces": "addressSpaces",
    "admin_enabled": "adminEnabled",
    "admin_password": "adminPassword",
    "admin_username": "adminUsername",
    "admin_users": "adminUsers",
    "administrator_login": "administratorLogin",
    "administrator_login_password": "administratorLoginPassword",
    "agent_pool_profile": "agentPoolProfile",
    "agent_pool_profiles": "agentPoolProfiles",
    "alert_notifications": "alertNotifications",
    "alerts_to_admins": "alertsToAdmins",
    "allocated_outbound_ports": "allocatedOutboundPorts",
    "allocation_method": "allocationMethod",
    "allocation_policy": "allocationPolicy",
    "allow_branch_to_branch_traffic": "allowBranchToBranchTraffic",
    "allow_claim": "allowClaim",
    "allow_classic_operations": "allowClassicOperations",
    "allow_forwarded_traffic": "allowForwardedTraffic",
    "allow_gateway_transit": "allowGatewayTransit",
    "allow_updates": "allowUpdates",
    "allow_virtual_network_access": "allowVirtualNetworkAccess",
    "allow_vnet_to_vnet_traffic": "allowVnetToVnetTraffic",
    "alternate_name": "alternateName",
    "api_key": "apiKey",
    "api_management_name": "apiManagementName",
    "api_name": "apiName",
    "api_server_authorized_ip_ranges": "apiServerAuthorizedIpRanges",
    "apns_credential": "apnsCredential",
    "app_id": "appId",
    "app_service_certificate_not_renewable_reasons": "appServiceCertificateNotRenewableReasons",
    "app_service_environment_id": "appServiceEnvironmentId",
    "app_service_name": "appServiceName",
    "app_service_plan_id": "appServicePlanId",
    "app_service_slot_name": "appServiceSlotName",
    "app_settings": "appSettings",
    "application_consistent_snapshot_frequency_in_minutes": "applicationConsistentSnapshotFrequencyInMinutes",
    "application_id": "applicationId",
    "application_insights": "applicationInsights",
    "application_insights_id": "applicationInsightsId",
    "application_security_group_id": "applicationSecurityGroupId",
    "application_type": "applicationType",
    "applied_dns_servers": "appliedDnsServers",
    "approval_required": "approvalRequired",
    "arm_role_receivers": "armRoleReceivers",
    "artifacts_storage_account_id": "artifactsStorageAccountId",
    "assignable_scopes": "assignableScopes",
    "auth_settings": "authSettings",
    "authentication_certificates": "authenticationCertificates",
    "authentication_configuration": "authenticationConfiguration",
    "authorization_endpoint": "authorizationEndpoint",
    "authorization_key": "authorizationKey",
    "authorization_methods": "authorizationMethods",
    "authorization_use_status": "authorizationUseStatus",
    "auto_approval_subscription_ids": "autoApprovalSubscriptionIds",
    "auto_delete_on_idle": "autoDeleteOnIdle",
    "auto_inflate_enabled": "autoInflateEnabled",
    "auto_mitigate": "autoMitigate",
    "auto_renew": "autoRenew",
    "auto_scale": "autoScale",
    "auto_start": "autoStart",
    "auto_upgrade_minor_version": "autoUpgradeMinorVersion",
    "automatic_os_upgrade": "automaticOsUpgrade",
    "automation_account_name": "automationAccountName",
    "automation_runbook_receivers": "automationRunbookReceivers",
    "autoscale_configuration": "autoscaleConfiguration",
    "auxiliary_tenant_ids": "auxiliaryTenantIds",
    "availability_set_id": "availabilitySetId",
    "availability_zones": "availabilityZones",
    "available_to_other_tenants": "availableToOtherTenants",
    "azure_active_directory": "azureActiveDirectory",
    "azure_active_directory_authentications": "azureActiveDirectoryAuthentications",
    "azure_app_push_receivers": "azureAppPushReceivers",
    "azure_asn": "azureAsn",
    "azure_firewall_name": "azureFirewallName",
    "azure_function_receivers": "azureFunctionReceivers",
    "backend_address_pool_id": "backendAddressPoolId",
    "backend_address_pools": "backendAddressPools",
    "backend_http_settings": "backendHttpSettings",
    "backend_ip_configuration_id": "backendIpConfigurationId",
    "backend_ip_configurations": "backendIpConfigurations",
    "backend_pool_health_probes": "backendPoolHealthProbes",
    "backend_pool_load_balancings": "backendPoolLoadBalancings",
    "backend_pools": "backendPools",
    "backend_port": "backendPort",
    "backup_blob_container_uri": "backupBlobContainerUri",
    "backup_policy_id": "backupPolicyId",
    "bandwidth_in_mbps": "bandwidthInMbps",
    "batch_frequency_in_seconds": "batchFrequencyInSeconds",
    "bearer_token_sending_methods": "bearerTokenSendingMethods",
    "bgp_settings": "bgpSettings",
    "boot_diagnostics": "bootDiagnostics",
    "bot_name": "botName",
    "capture_description": "captureDescription",
    "catalog_info": "catalogInfo",
    "certificate_common_names": "certificateCommonNames",
    "certificate_content": "certificateContent",
    "certificate_data": "certificateData",
    "certificate_permissions": "certificatePermissions",
    "certificate_policy": "certificatePolicy",
    "client_affinity_enabled": "clientAffinityEnabled",
    "client_authentication_methods": "clientAuthenticationMethods",
    "client_cert_enabled": "clientCertEnabled",
    "client_certificate_password": "clientCertificatePassword",
    "client_certificate_path": "clientCertificatePath",
    "client_certificate_thumbprints": "clientCertificateThumbprints",
    "client_id": "clientId",
    "client_registration_endpoint": "clientRegistrationEndpoint",
    "client_revoked_certificates": "clientRevokedCertificates",
    "client_root_certificates": "clientRootCertificates",
    "client_secret": "clientSecret",
    "cluster_code_version": "clusterCodeVersion",
    "cluster_endpoint": "clusterEndpoint",
    "cluster_name": "clusterName",
    "cluster_version": "clusterVersion",
    "compatibility_level": "compatibilityLevel",
    "component_version": "componentVersion",
    "configuration_name": "configurationName",
    "connection_configuration": "connectionConfiguration",
    "connection_string": "connectionString",
    "connection_strings": "connectionStrings",
    "consistency_policy": "consistencyPolicy",
    "consumer_group": "consumerGroup",
    "container_access_type": "containerAccessType",
    "container_configuration": "containerConfiguration",
    "container_name": "containerName",
    "container_network_interface": "containerNetworkInterface",
    "container_network_interface_ids": "containerNetworkInterfaceIds",
    "content_embedded": "contentEmbedded",
    "content_type": "contentType",
    "content_types_to_compresses": "contentTypesToCompresses",
    "correlation_filter": "correlationFilter",
    "cors_configuration": "corsConfiguration",
    "cosmosdb_throughput": "cosmosdbThroughput",
    "create_mode": "createMode",
    "create_option": "createOption",
    "creation_date": "creationDate",
    "custom_block_response_body": "customBlockResponseBody",
    "custom_block_response_status_code": "customBlockResponseStatusCode",
    "custom_domain": "customDomain",
    "custom_error_configurations": "customErrorConfigurations",
    "custom_headers": "customHeaders",
    "custom_rules": "customRules",
    "custom_setup_script": "customSetupScript",
    "daily_recurrence": "dailyRecurrence",
    "dashboard_properties": "dashboardProperties",
    "data_disks": "dataDisks",
    "data_factory_name": "dataFactoryName",
    "data_format": "dataFormat",
    "data_ingestion_uri": "dataIngestionUri",
    "data_locale": "dataLocale",
    "data_plane_fqdn": "dataPlaneFqdn",
    "database_name": "databaseName",
    "date_format": "dateFormat",
    "db_dtu_max": "dbDtuMax",
    "db_dtu_min": "dbDtuMin",
    "ddos_protection_plan": "ddosProtectionPlan",
    "dead_lettering_on_filter_evaluation_exceptions": "deadLetteringOnFilterEvaluationExceptions",
    "dead_lettering_on_message_expiration": "deadLetteringOnMessageExpiration",
    "default_action": "defaultAction",
    "default_hostname": "defaultHostname",
    "default_local_network_gateway_id": "defaultLocalNetworkGatewayId",
    "default_message_ttl": "defaultMessageTtl",
    "default_node_pool": "defaultNodePool",
    "default_premium_storage_account_id": "defaultPremiumStorageAccountId",
    "default_primary_connection_string": "defaultPrimaryConnectionString",
    "default_primary_key": "defaultPrimaryKey",
    "default_scope": "defaultScope",
    "default_secondary_connection_string": "defaultSecondaryConnectionString",
    "default_secondary_key": "defaultSecondaryKey",
    "default_secondary_location": "defaultSecondaryLocation",
    "default_site_hostname": "defaultSiteHostname",
    "default_storage_account_id": "defaultStorageAccountId",
    "default_store_account_name": "defaultStoreAccountName",
    "default_ttl_seconds": "defaultTtlSeconds",
    "default_version": "defaultVersion",
    "delete_data_disks_on_termination": "deleteDataDisksOnTermination",
    "delete_os_disk_on_termination": "deleteOsDiskOnTermination",
    "deployment_mode": "deploymentMode",
    "destination_address_prefix": "destinationAddressPrefix",
    "destination_address_prefixes": "destinationAddressPrefixes",
    "destination_application_security_group_ids": "destinationApplicationSecurityGroupIds",
    "destination_port_range": "destinationPortRange",
    "destination_port_ranges": "destinationPortRanges",
    "developer_app_insights_api_key": "developerAppInsightsApiKey",
    "developer_app_insights_application_id": "developerAppInsightsApplicationId",
    "developer_app_insights_key": "developerAppInsightsKey",
    "device_connect": "deviceConnect",
    "device_provisioning_host_name": "deviceProvisioningHostName",
    "diagnostics_config": "diagnosticsConfig",
    "diagnostics_profile": "diagnosticsProfile",
    "disable_bgp_route_propagation": "disableBgpRoutePropagation",
    "disable_correlation_request_id": "disableCorrelationRequestId",
    "disable_outbound_snat": "disableOutboundSnat",
    "disable_terraform_partner_id": "disableTerraformPartnerId",
    "disable_vpn_encryption": "disableVpnEncryption",
    "disabled_ssl_protocols": "disabledSslProtocols",
    "disallow_public_ip_address": "disallowPublicIpAddress",
    "disk_iops_read_write": "diskIopsReadWrite",
    "disk_mbps_read_write": "diskMbpsReadWrite",
    "disk_size_gb": "diskSizeGb",
    "display_name": "displayName",
    "distinguished_name": "distinguishedName",
    "dns_configs": "dnsConfigs",
    "dns_name": "dnsName",
    "dns_name_label": "dnsNameLabel",
    "dns_prefix": "dnsPrefix",
    "dns_servers": "dnsServers",
    "domain_name_label": "domainNameLabel",
    "domain_verification_token": "domainVerificationToken",
    "dsc_primary_access_key": "dscPrimaryAccessKey",
    "dsc_secondary_access_key": "dscSecondaryAccessKey",
    "dsc_server_endpoint": "dscServerEndpoint",
    "duplicate_detection_history_time_window": "duplicateDetectionHistoryTimeWindow",
    "edge_ssh_endpoint": "edgeSshEndpoint",
    "elastic_pool_name": "elasticPoolName",
    "elastic_pool_properties": "elasticPoolProperties",
    "email_action": "emailAction",
    "email_address": "emailAddress",
    "email_password": "emailPassword",
    "email_receivers": "emailReceivers",
    "enable_accelerated_networking": "enableAcceleratedNetworking",
    "enable_advanced_threat_protection": "enableAdvancedThreatProtection",
    "enable_auto_scaling": "enableAutoScaling",
    "enable_automatic_failover": "enableAutomaticFailover",
    "enable_batched_operations": "enableBatchedOperations",
    "enable_bgp": "enableBgp",
    "enable_blob_encryption": "enableBlobEncryption",
    "enable_builtin_logging": "enableBuiltinLogging",
    "enable_express": "enableExpress",
    "enable_file_encryption": "enableFileEncryption",
    "enable_filtering_messages_before_publishing": "enableFilteringMessagesBeforePublishing",
    "enable_floating_ip": "enableFloatingIp",
    "enable_http2": "enableHttp2",
    "enable_https_traffic_only": "enableHttpsTrafficOnly",
    "enable_ip_forwarding": "enableIpForwarding",
    "enable_multiple_write_locations": "enableMultipleWriteLocations",
    "enable_node_public_ip": "enableNodePublicIp",
    "enable_non_ssl_port": "enableNonSslPort",
    "enable_partitioning": "enablePartitioning",
    "enable_pod_security_policy": "enablePodSecurityPolicy",
    "enable_power_bi_service": "enablePowerBiService",
    "enable_tcp_reset": "enableTcpReset",
    "enabled_for_deployment": "enabledForDeployment",
    "enabled_for_disk_encryption": "enabledForDiskEncryption",
    "enabled_for_template_deployment": "enabledForTemplateDeployment",
    "encryption_settings": "encryptionSettings",
    "encryption_state": "encryptionState",
    "encryption_type": "encryptionType",
    "end_date": "endDate",
    "end_ip": "endIp",
    "end_ip_address": "endIpAddress",
    "end_time": "endTime",
    "endpoint_location": "endpointLocation",
    "endpoint_monitor_status": "endpointMonitorStatus",
    "endpoint_names": "endpointNames",
    "endpoint_status": "endpointStatus",
    "enforce_backend_pools_certificate_name_check": "enforceBackendPoolsCertificateNameCheck",
    "enforce_private_link_endpoint_network_policies": "enforcePrivateLinkEndpointNetworkPolicies",
    "enforce_private_link_service_network_policies": "enforcePrivateLinkServiceNetworkPolicies",
    "error_action_storage_queue": "errorActionStorageQueue",
    "error_action_web": "errorActionWeb",
    "evaluator_type": "evaluatorType",
    "event_delivery_schema": "eventDeliverySchema",
    "event_hub_events_endpoint": "eventHubEventsEndpoint",
    "event_hub_events_path": "eventHubEventsPath",
    "event_hub_operations_endpoint": "eventHubOperationsEndpoint",
    "event_hub_operations_path": "eventHubOperationsPath",
    "eventhub_authorization_rule_id": "eventhubAuthorizationRuleId",
    "eventhub_consumer_group_name": "eventhubConsumerGroupName",
    "eventhub_endpoint": "eventhubEndpoint",
    "eventhub_endpoint_name": "eventhubEndpointName",
    "eventhub_id": "eventhubId",
    "eventhub_name": "eventhubName",
    "events_late_arrival_max_delay_in_seconds": "eventsLateArrivalMaxDelayInSeconds",
    "events_out_of_order_max_delay_in_seconds": "eventsOutOfOrderMaxDelayInSeconds",
    "events_out_of_order_policy": "eventsOutOfOrderPolicy",
    "eviction_policy": "evictionPolicy",
    "exclude_from_latest": "excludeFromLatest",
    "expiration_date": "expirationDate",
    "expiration_time": "expirationTime",
    "expiry_time": "expiryTime",
    "express_route_circuit_id": "expressRouteCircuitId",
    "express_route_circuit_name": "expressRouteCircuitName",
    "express_route_gateway_bypass": "expressRouteGatewayBypass",
    "external_id": "externalId",
    "fabric_settings": "fabricSettings",
    "fact_data": "factData",
    "failover_policies": "failoverPolicies",
    "fallback_route": "fallbackRoute",
    "file_name_format": "fileNameFormat",
    "file_upload": "fileUpload",
    "filter_type": "filterType",
    "firewall_allow_azure_ips": "firewallAllowAzureIps",
    "firewall_state": "firewallState",
    "first_name": "firstName",
    "fixed_scale": "fixedScale",
    "forward_dead_lettered_messages_to": "forwardDeadLetteredMessagesTo",
    "forward_to": "forwardTo",
    "friendly_name": "friendlyName",
    "frontend_endpoint_ids": "frontendEndpointIds",
    "frontend_endpoints": "frontendEndpoints",
    "frontend_ip_configuration_id": "frontendIpConfigurationId",
    "frontend_ip_configuration_name": "frontendIpConfigurationName",
    "frontend_ip_configurations": "frontendIpConfigurations",
    "frontend_port": "frontendPort",
    "frontend_port_end": "frontendPortEnd",
    "frontend_port_start": "frontendPortStart",
    "frontend_ports": "frontendPorts",
    "fully_qualified_domain_name": "fullyQualifiedDomainName",
    "function_alias": "functionAlias",
    "gallery_image_reference": "galleryImageReference",
    "gallery_name": "galleryName",
    "gateway_address": "gatewayAddress",
    "gateway_ip_configurations": "gatewayIpConfigurations",
    "gateway_regional_url": "gatewayRegionalUrl",
    "gateway_url": "gatewayUrl",
    "gcm_credential": "gcmCredential",
    "geo_filters": "geoFilters",
    "geo_locations": "geoLocations",
    "geo_mappings": "geoMappings",
    "georeplication_locations": "georeplicationLocations",
    "github_configuration": "githubConfiguration",
    "grant_types": "grantTypes",
    "group_id": "groupId",
    "group_name": "groupName",
    "has_immutability_policy": "hasImmutabilityPolicy",
    "has_legal_hold": "hasLegalHold",
    "health_probe_id": "healthProbeId",
    "host_name": "hostName",
    "host_names": "hostNames",
    "host_suffix": "hostSuffix",
    "hostname_configuration": "hostnameConfiguration",
    "hot_cache_period": "hotCachePeriod",
    "hourly_recurrence": "hourlyRecurrence",
    "http_listeners": "httpListeners",
    "https_endpoint": "httpsEndpoint",
    "https_only": "httpsOnly",
    "hybrid_connection_endpoint": "hybridConnectionEndpoint",
    "id_scope": "idScope",
    "identifier_uris": "identifierUris",
    "idle_timeout_in_minutes": "idleTimeoutInMinutes",
    "ignore_missing_vnet_service_endpoint": "ignoreMissingVnetServiceEndpoint",
    "image_name": "imageName",
    "image_reference_id": "imageReferenceId",
    "image_registry_credentials": "imageRegistryCredentials",
    "import_": "import",
    "inbound_nat_rules": "inboundNatRules",
    "included_event_types": "includedEventTypes",
    "input_mapping_default_values": "inputMappingDefaultValues",
    "input_mapping_fields": "inputMappingFields",
    "input_schema": "inputSchema",
    "instrumentation_key": "instrumentationKey",
    "integration_runtime_name": "integrationRuntimeName",
    "intermediate_thumbprint": "intermediateThumbprint",
    "internal_dns_name_label": "internalDnsNameLabel",
    "internal_fqdn": "internalFqdn",
    "interval_in_seconds": "intervalInSeconds",
    "iot_dps_name": "iotDpsName",
    "iothub_name": "iothubName",
    "iothub_namespace": "iothubNamespace",
    "ip_address": "ipAddress",
    "ip_address_type": "ipAddressType",
    "ip_configuration": "ipConfiguration",
    "ip_configuration_name": "ipConfigurationName",
    "ip_configurations": "ipConfigurations",
    "ip_filter_rules": "ipFilterRules",
    "ip_prefix": "ipPrefix",
    "ip_range_filter": "ipRangeFilter",
    "ip_rules": "ipRules",
    "ip_version": "ipVersion",
    "ipsec_policy": "ipsecPolicy",
    "ipv4_firewall_rules": "ipv4FirewallRules",
    "is_compression_enabled": "isCompressionEnabled",
    "is_current": "isCurrent",
    "is_hns_enabled": "isHnsEnabled",
    "is_http_allowed": "isHttpAllowed",
    "is_https_allowed": "isHttpsAllowed",
    "is_online": "isOnline",
    "is_private_key_external": "isPrivateKeyExternal",
    "is_virtual_network_filter_enabled": "isVirtualNetworkFilterEnabled",
    "is_xenon": "isXenon",
    "issue_date": "issueDate",
    "itsm_receivers": "itsmReceivers",
    "job_collection_name": "jobCollectionName",
    "job_id": "jobId",
    "job_schedule_id": "jobScheduleId",
    "kafka_enabled": "kafkaEnabled",
    "key_id": "keyId",
    "key_opts": "keyOpts",
    "key_permissions": "keyPermissions",
    "key_size": "keySize",
    "key_type": "keyType",
    "key_vault_id": "keyVaultId",
    "key_vault_reference": "keyVaultReference",
    "key_vault_secret_id": "keyVaultSecretId",
    "kube_admin_config": "kubeAdminConfig",
    "kube_admin_config_raw": "kubeAdminConfigRaw",
    "kube_config": "kubeConfig",
    "kube_config_raw": "kubeConfigRaw",
    "kubernetes_cluster_id": "kubernetesClusterId",
    "kubernetes_version": "kubernetesVersion",
    "lab_name": "labName",
    "lab_subnet_name": "labSubnetName",
    "lab_virtual_network_id": "labVirtualNetworkId",
    "landing_page_url": "landingPageUrl",
    "last_name": "lastName",
    "license_text_link": "licenseTextLink",
    "license_type": "licenseType",
    "linked_hubs": "linkedHubs",
    "linked_service_name": "linkedServiceName",
    "linked_service_properties": "linkedServiceProperties",
    "linux_profile": "linuxProfile",
    "load_balancer_enabled": "loadBalancerEnabled",
    "load_balancer_frontend_ip_configuration_ids": "loadBalancerFrontendIpConfigurationIds",
    "load_balancer_rules": "loadBalancerRules",
    "load_balancing_rules": "loadBalancingRules",
    "load_distribution": "loadDistribution",
    "loadbalancer_id": "loadbalancerId",
    "local_file_path": "localFilePath",
    "local_network_gateway_id": "localNetworkGatewayId",
    "lock_duration": "lockDuration",
    "lock_level": "lockLevel",
    "log_analytics_destination_type": "logAnalyticsDestinationType",
    "log_analytics_workspace_id": "logAnalyticsWorkspaceId",
    "log_progress": "logProgress",
    "log_verbose": "logVerbose",
    "logic_app_id": "logicAppId",
    "logic_app_receivers": "logicAppReceivers",
    "login_server": "loginServer",
    "luis_app_ids": "luisAppIds",
    "luis_key": "luisKey",
    "mac_address": "macAddress",
    "managed_disk_id": "managedDiskId",
    "managed_disks": "managedDisks",
    "managed_image_id": "managedImageId",
    "managed_resource_group_id": "managedResourceGroupId",
    "managed_resource_group_name": "managedResourceGroupName",
    "managed_rules": "managedRules",
    "management_api_url": "managementApiUrl",
    "management_endpoint": "managementEndpoint",
    "management_group_id": "managementGroupId",
    "mapping_rule_name": "mappingRuleName",
    "master_profile": "masterProfile",
    "max_chunk_size_in_bytes": "maxChunkSizeInBytes",
    "max_count": "maxCount",
    "max_delivery_count": "maxDeliveryCount",
    "max_number_of_record_sets": "maxNumberOfRecordSets",
    "max_number_of_virtual_network_links": "maxNumberOfVirtualNetworkLinks",
    "max_number_of_virtual_network_links_with_registration": "maxNumberOfVirtualNetworkLinksWithRegistration",
    "max_parallel_executions_per_node": "maxParallelExecutionsPerNode",
    "max_pods": "maxPods",
    "max_size_bytes": "maxSizeBytes",
    "max_size_gb": "maxSizeGb",
    "max_size_in_megabytes": "maxSizeInMegabytes",
    "max_tasks_per_node": "maxTasksPerNode",
    "maximum_bytes_per_packet": "maximumBytesPerPacket",
    "maximum_bytes_per_session": "maximumBytesPerSession",
    "maximum_capture_duration": "maximumCaptureDuration",
    "maximum_elastic_worker_count": "maximumElasticWorkerCount",
    "maximum_number_of_workers": "maximumNumberOfWorkers",
    "maximum_throughput_units": "maximumThroughputUnits",
    "message_retention": "messageRetention",
    "metadata_endpoint": "metadataEndpoint",
    "metric_id": "metricId",
    "metric_name": "metricName",
    "microsoft_app_id": "microsoftAppId",
    "microsoft_peering_config": "microsoftPeeringConfig",
    "min_child_endpoints": "minChildEndpoints",
    "min_count": "minCount",
    "minimum_tls_version": "minimumTlsVersion",
    "module_link": "moduleLink",
    "monitor_configs": "monitorConfigs",
    "month_days": "monthDays",
    "monthly_occurrences": "monthlyOccurrences",
    "msi_endpoint": "msiEndpoint",
    "name_servers": "nameServers",
    "namespace_name": "namespaceName",
    "namespace_type": "namespaceType",
    "nat_gateway_id": "natGatewayId",
    "nat_ip_configurations": "natIpConfigurations",
    "nat_rule_id": "natRuleId",
    "network_acls": "networkAcls",
    "network_interface_id": "networkInterfaceId",
    "network_interface_ids": "networkInterfaceIds",
    "network_profile": "networkProfile",
    "network_profile_id": "networkProfileId",
    "network_profiles": "networkProfiles",
    "network_rule_set": "networkRuleSet",
    "network_rules": "networkRules",
    "network_rulesets": "networkRulesets",
    "network_security_group_id": "networkSecurityGroupId",
    "network_security_group_name": "networkSecurityGroupName",
    "network_watcher_name": "networkWatcherName",
    "next_hop_in_ip_address": "nextHopInIpAddress",
    "next_hop_type": "nextHopType",
    "node_agent_sku_id": "nodeAgentSkuId",
    "node_count": "nodeCount",
    "node_resource_group": "nodeResourceGroup",
    "node_size": "nodeSize",
    "node_taints": "nodeTaints",
    "node_types": "nodeTypes",
    "not_before_date": "notBeforeDate",
    "not_scopes": "notScopes",
    "notification_hub_name": "notificationHubName",
    "notification_sender_email": "notificationSenderEmail",
    "notification_settings": "notificationSettings",
    "number_of_nodes": "numberOfNodes",
    "number_of_probes": "numberOfProbes",
    "number_of_record_sets": "numberOfRecordSets",
    "oauth2_allow_implicit_flow": "oauth2AllowImplicitFlow",
    "object_id": "objectId",
    "offer_type": "offerType",
    "office365_local_breakout_category": "office365LocalBreakoutCategory",
    "operation_id": "operationId",
    "optimization_type": "optimizationType",
    "orchestration_platform": "orchestrationPlatform",
    "origin_host_header": "originHostHeader",
    "origin_path": "originPath",
    "os_disk": "osDisk",
    "os_disk_size_gb": "osDiskSizeGb",
    "os_profile": "osProfile",
    "os_profile_linux_config": "osProfileLinuxConfig",
    "os_profile_secrets": "osProfileSecrets",
    "os_profile_windows_config": "osProfileWindowsConfig",
    "os_type": "osType",
    "outbound_ip_addresses": "outboundIpAddresses",
    "output_error_policy": "outputErrorPolicy",
    "parameters_body": "parametersBody",
    "parent_management_group_id": "parentManagementGroupId",
    "partition_count": "partitionCount",
    "partition_ids": "partitionIds",
    "partition_key": "partitionKey",
    "partition_key_path": "partitionKeyPath",
    "partner_id": "partnerId",
    "partner_namespace_id": "partnerNamespaceId",
    "partner_servers": "partnerServers",
    "patch_schedules": "patchSchedules",
    "path_pattern": "pathPattern",
    "peer_asn": "peerAsn",
    "peer_virtual_network_gateway_id": "peerVirtualNetworkGatewayId",
    "peering_location": "peeringLocation",
    "peering_type": "peeringType",
    "per_database_settings": "perDatabaseSettings",
    "per_site_scaling": "perSiteScaling",
    "pfx_blob": "pfxBlob",
    "pipeline_name": "pipelineName",
    "pipeline_parameters": "pipelineParameters",
    "platform_fault_domain_count": "platformFaultDomainCount",
    "platform_update_domain_count": "platformUpdateDomainCount",
    "policy_definition_id": "policyDefinitionId",
    "policy_definitions": "policyDefinitions",
    "policy_rule": "policyRule",
    "policy_set_name": "policySetName",
    "policy_settings": "policySettings",
    "policy_type": "policyType",
    "pool_allocation_mode": "poolAllocationMode",
    "pool_size": "poolSize",
    "portal_url": "portalUrl",
    "possible_outbound_ip_addresses": "possibleOutboundIpAddresses",
    "prefix_length": "prefixLength",
    "premium_data_disk_storage_account_id": "premiumDataDiskStorageAccountId",
    "primary_access_key": "primaryAccessKey",
    "primary_azure_port": "primaryAzurePort",
    "primary_blob_connection_string": "primaryBlobConnectionString",
    "primary_blob_endpoint": "primaryBlobEndpoint",
    "primary_blob_host": "primaryBlobHost",
    "primary_connection_string": "primaryConnectionString",
    "primary_dfs_endpoint": "primaryDfsEndpoint",
    "primary_dfs_host": "primaryDfsHost",
    "primary_file_endpoint": "primaryFileEndpoint",
    "primary_file_host": "primaryFileHost",
    "primary_key": "primaryKey",
    "primary_location": "primaryLocation",
    "primary_master_key": "primaryMasterKey",
    "primary_network_interface_id": "primaryNetworkInterfaceId",
    "primary_peer_address_prefix": "primaryPeerAddressPrefix",
    "primary_queue_endpoint": "primaryQueueEndpoint",
    "primary_queue_host": "primaryQueueHost",
    "primary_readonly_master_key": "primaryReadonlyMasterKey",
    "primary_shared_key": "primarySharedKey",
    "primary_table_endpoint": "primaryTableEndpoint",
    "primary_table_host": "primaryTableHost",
    "primary_web_endpoint": "primaryWebEndpoint",
    "primary_web_host": "primaryWebHost",
    "principal_id": "principalId",
    "principal_type": "principalType",
    "privacy_policy_link": "privacyPolicyLink",
    "privacy_statement_uri": "privacyStatementUri",
    "private_dns_zone_name": "privateDnsZoneName",
    "private_ip_address": "privateIpAddress",
    "private_ip_addresses": "privateIpAddresses",
    "private_service_connection": "privateServiceConnection",
    "private_static_ip_address": "privateStaticIpAddress",
    "probe_id": "probeId",
    "probe_path": "probePath",
    "product_id": "productId",
    "product_type": "productType",
    "profile_name": "profileName",
    "profile_status": "profileStatus",
    "protected_settings": "protectedSettings",
    "proximity_placement_group_id": "proximityPlacementGroupId",
    "public_data": "publicData",
    "public_ip_address_allocation": "publicIpAddressAllocation",
    "public_ip_address_ids": "publicIpAddressIds",
    "public_ip_addresses": "publicIpAddresses",
    "public_ip_prefix_id": "publicIpPrefixId",
    "public_ip_prefix_ids": "publicIpPrefixIds",
    "public_port": "publicPort",
    "publish_content_link": "publishContentLink",
    "publisher_email": "publisherEmail",
    "publisher_name": "publisherName",
    "querypool_connection_mode": "querypoolConnectionMode",
    "querystring_caching_behaviour": "querystringCachingBehaviour",
    "queue_name": "queueName",
    "queue_properties": "queueProperties",
    "radius_server": "radiusServer",
    "read_endpoints": "readEndpoints",
    "read_permissions": "readPermissions",
    "read_scale": "readScale",
    "read_write_endpoint_failover_policy": "readWriteEndpointFailoverPolicy",
    "readonly_endpoint_failover_policy": "readonlyEndpointFailoverPolicy",
    "recovery_fabric_name": "recoveryFabricName",
    "recovery_point_retention_in_minutes": "recoveryPointRetentionInMinutes",
    "recovery_replication_policy_id": "recoveryReplicationPolicyId",
    "recovery_source_protection_container_name": "recoverySourceProtectionContainerName",
    "recovery_target_protection_container_id": "recoveryTargetProtectionContainerId",
    "recovery_vault_name": "recoveryVaultName",
    "redirect_configurations": "redirectConfigurations",
    "redirect_url": "redirectUrl",
    "redis_cache_name": "redisCacheName",
    "redis_configuration": "redisConfiguration",
    "registration_enabled": "registrationEnabled",
    "registration_virtual_network_ids": "registrationVirtualNetworkIds",
    "registry_name": "registryName",
    "registry_read": "registryRead",
    "registry_write": "registryWrite",
    "relative_path": "relativePath",
    "relay_namespace_name": "relayNamespaceName",
    "release_note_uri": "releaseNoteUri",
    "reliability_level": "reliabilityLevel",
    "remote_file_path": "remoteFilePath",
    "remote_virtual_network_id": "remoteVirtualNetworkId",
    "replica_count": "replicaCount",
    "reply_urls": "replyUrls",
    "request_path": "requestPath",
    "request_routing_rules": "requestRoutingRules",
    "requested_service_objective_id": "requestedServiceObjectiveId",
    "requested_service_objective_name": "requestedServiceObjectiveName",
    "requires_client_authorization": "requiresClientAuthorization",
    "requires_duplicate_detection": "requiresDuplicateDetection",
    "requires_session": "requiresSession",
    "resolution_virtual_network_ids": "resolutionVirtualNetworkIds",
    "resource_group_name": "resourceGroupName",
    "resource_guid": "resourceGuid",
    "resource_id": "resourceId",
    "resource_owner_password": "resourceOwnerPassword",
    "resource_owner_username": "resourceOwnerUsername",
    "restart_policy": "restartPolicy",
    "restore_point_in_time": "restorePointInTime",
    "retention_daily": "retentionDaily",
    "retention_in_days": "retentionInDays",
    "retention_monthly": "retentionMonthly",
    "retention_policy": "retentionPolicy",
    "retention_weekly": "retentionWeekly",
    "retention_yearly": "retentionYearly",
    "retry_enabled": "retryEnabled",
    "retry_policy": "retryPolicy",
    "reverse_fqdn": "reverseFqdn",
    "reverse_proxy_certificate": "reverseProxyCertificate",
    "rewrite_rule_sets": "rewriteRuleSets",
    "role_based_access_control": "roleBasedAccessControl",
    "role_definition_id": "roleDefinitionId",
    "role_definition_name": "roleDefinitionName",
    "rolling_upgrade_policy": "rollingUpgradePolicy",
    "root_thumbprint": "rootThumbprint",
    "route_table_id": "routeTableId",
    "route_table_name": "routeTableName",
    "routing_rules": "routingRules",
    "routing_weight": "routingWeight",
    "row_key": "rowKey",
    "run_on": "runOn",
    "runbook_name": "runbookName",
    "runbook_type": "runbookType",
    "sampling_percentage": "samplingPercentage",
    "scale_unit": "scaleUnit",
    "schedule_name": "scheduleName",
    "schema_columns": "schemaColumns",
    "schema_id": "schemaId",
    "scm_url": "scmUrl",
    "secondary_access_key": "secondaryAccessKey",
    "secondary_azure_port": "secondaryAzurePort",
    "secondary_blob_connection_string": "secondaryBlobConnectionString",
    "secondary_blob_endpoint": "secondaryBlobEndpoint",
    "secondary_blob_host": "secondaryBlobHost",
    "secondary_connection_string": "secondaryConnectionString",
    "secondary_dfs_endpoint": "secondaryDfsEndpoint",
    "secondary_dfs_host": "secondaryDfsHost",
    "secondary_file_endpoint": "secondaryFileEndpoint",
    "secondary_file_host": "secondaryFileHost",
    "secondary_key": "secondaryKey",
    "secondary_location": "secondaryLocation",
    "secondary_master_key": "secondaryMasterKey",
    "secondary_peer_address_prefix": "secondaryPeerAddressPrefix",
    "secondary_queue_endpoint": "secondaryQueueEndpoint",
    "secondary_queue_host": "secondaryQueueHost",
    "secondary_readonly_master_key": "secondaryReadonlyMasterKey",
    "secondary_shared_key": "secondarySharedKey",
    "secondary_table_endpoint": "secondaryTableEndpoint",
    "secondary_table_host": "secondaryTableHost",
    "secondary_web_endpoint": "secondaryWebEndpoint",
    "secondary_web_host": "secondaryWebHost",
    "secret_id": "secretId",
    "secret_permissions": "secretPermissions",
    "security_provider_name": "securityProviderName",
    "security_rules": "securityRules",
    "server_full_name": "serverFullName",
    "server_name": "serverName",
    "server_port": "serverPort",
    "service_connect": "serviceConnect",
    "service_endpoints": "serviceEndpoints",
    "service_fabric_cluster": "serviceFabricCluster",
    "service_key": "serviceKey",
    "service_level": "serviceLevel",
    "service_operations_host_name": "serviceOperationsHostName",
    "service_principal": "servicePrincipal",
    "service_principal_id": "servicePrincipalId",
    "service_principal_key": "servicePrincipalKey",
    "service_provider_name": "serviceProviderName",
    "service_provider_provisioning_state": "serviceProviderProvisioningState",
    "service_uri": "serviceUri",
    "service_url": "serviceUrl",
    "servicebus_endpoint": "servicebusEndpoint",
    "servicebus_namespace": "servicebusNamespace",
    "servicebus_rule_id": "servicebusRuleId",
    "shard_count": "shardCount",
    "shard_key": "shardKey",
    "share_name": "shareName",
    "shared_access_policies": "sharedAccessPolicies",
    "shared_access_policy_key": "sharedAccessPolicyKey",
    "shared_access_policy_name": "sharedAccessPolicyName",
    "shared_key": "sharedKey",
    "short_name": "shortName",
    "sign_in": "signIn",
    "sign_up": "signUp",
    "signed_certificate_thumbprint": "signedCertificateThumbprint",
    "single_placement_group": "singlePlacementGroup",
    "site_config": "siteConfig",
    "site_credential": "siteCredential",
    "size_in_tb": "sizeInTb",
    "skip_credentials_validation": "skipCredentialsValidation",
    "skip_provider_registration": "skipProviderRegistration",
    "skip_service_principal_aad_check": "skipServicePrincipalAadCheck",
    "sku_name": "skuName",
    "sms_receivers": "smsReceivers",
    "soap_pass_through": "soapPassThrough",
    "soft_delete_period": "softDeletePeriod",
    "solution_name": "solutionName",
    "source_address_prefix": "sourceAddressPrefix",
    "source_address_prefixes": "sourceAddressPrefixes",
    "source_application_security_group_ids": "sourceApplicationSecurityGroupIds",
    "source_content": "sourceContent",
    "source_control": "sourceControl",
    "source_database_deletion_date": "sourceDatabaseDeletionDate",
    "source_database_id": "sourceDatabaseId",
    "source_network_id": "sourceNetworkId",
    "source_port_range": "sourcePortRange",
    "source_port_ranges": "sourcePortRanges",
    "source_recovery_fabric_name": "sourceRecoveryFabricName",
    "source_recovery_protection_container_name": "sourceRecoveryProtectionContainerName",
    "source_resource_id": "sourceResourceId",
    "source_uri": "sourceUri",
    "source_virtual_machine_id": "sourceVirtualMachineId",
    "source_vm_id": "sourceVmId",
    "sql_filter": "sqlFilter",
    "ssh_endpoint": "sshEndpoint",
    "ssh_key": "sshKey",
    "ssl_certificates": "sslCertificates",
    "ssl_enforcement": "sslEnforcement",
    "ssl_policies": "sslPolicies",
    "ssl_port": "sslPort",
    "ssl_state": "sslState",
    "start_date": "startDate",
    "start_ip": "startIp",
    "start_ip_address": "startIpAddress",
    "start_task": "startTask",
    "start_time": "startTime",
    "stop_pending_resize_operation": "stopPendingResizeOperation",
    "storage_account": "storageAccount",
    "storage_account_gen2": "storageAccountGen2",
    "storage_account_id": "storageAccountId",
    "storage_account_key": "storageAccountKey",
    "storage_account_name": "storageAccountName",
    "storage_account_type": "storageAccountType",
    "storage_accounts": "storageAccounts",
    "storage_blob_dead_letter_destination": "storageBlobDeadLetterDestination",
    "storage_connection_string": "storageConnectionString",
    "storage_container_name": "storageContainerName",
    "storage_data_disks": "storageDataDisks",
    "storage_image_reference": "storageImageReference",
    "storage_location": "storageLocation",
    "storage_os_disk": "storageOsDisk",
    "storage_permissions": "storagePermissions",
    "storage_profile": "storageProfile",
    "storage_profile_data_disks": "storageProfileDataDisks",
    "storage_profile_image_reference": "storageProfileImageReference",
    "storage_profile_os_disk": "storageProfileOsDisk",
    "storage_queue_endpoint": "storageQueueEndpoint",
    "storage_type": "storageType",
    "stream_analytics_job_name": "streamAnalyticsJobName",
    "streaming_units": "streamingUnits",
    "subject_filter": "subjectFilter",
    "subject_name": "subjectName",
    "subnet_id": "subnetId",
    "subscription_id": "subscriptionId",
    "subscription_ids": "subscriptionIds",
    "subscription_key_parameter_names": "subscriptionKeyParameterNames",
    "subscription_name": "subscriptionName",
    "subscription_required": "subscriptionRequired",
    "subscriptions_limit": "subscriptionsLimit",
    "support_ordering": "supportOrdering",
    "support_state": "supportState",
    "synthetic_monitor_id": "syntheticMonitorId",
    "table_name": "tableName",
    "target_availability_set_id": "targetAvailabilitySetId",
    "target_container_host_credentials_base64": "targetContainerHostCredentialsBase64",
    "target_container_host_resource_id": "targetContainerHostResourceId",
    "target_network_id": "targetNetworkId",
    "target_recovery_fabric_id": "targetRecoveryFabricId",
    "target_recovery_fabric_name": "targetRecoveryFabricName",
    "target_recovery_protection_container_id": "targetRecoveryProtectionContainerId",
    "target_regions": "targetRegions",
    "target_resource_group_id": "targetResourceGroupId",
    "target_resource_id": "targetResourceId",
    "task_type": "taskType",
    "template_body": "templateBody",
    "template_parameters": "templateParameters",
    "tenant_id": "tenantId",
    "threat_detection_policy": "threatDetectionPolicy",
    "thumbprint_algorithm": "thumbprintAlgorithm",
    "time_created": "timeCreated",
    "time_format": "timeFormat",
    "time_modified": "timeModified",
    "time_zone_id": "timeZoneId",
    "token_body_parameters": "tokenBodyParameters",
    "token_endpoint": "tokenEndpoint",
    "token_secret": "tokenSecret",
    "topic_name": "topicName",
    "traffic_routing_method": "trafficRoutingMethod",
    "transformation_query": "transformationQuery",
    "trusted_root_certificates": "trustedRootCertificates",
    "type_handler_version": "typeHandlerVersion",
    "unique_identifier": "uniqueIdentifier",
    "unique_keys": "uniqueKeys",
    "unique_name": "uniqueName",
    "upgrade_mode": "upgradeMode",
    "upgrade_policy_mode": "upgradePolicyMode",
    "url_path_maps": "urlPathMaps",
    "url_template": "urlTemplate",
    "use_msi": "useMsi",
    "use_policy_based_traffic_selectors": "usePolicyBasedTrafficSelectors",
    "use_remote_gateways": "useRemoteGateways",
    "user_id": "userId",
    "user_metadata": "userMetadata",
    "validity_in_years": "validityInYears",
    "vault_name": "vaultName",
    "vault_uri": "vaultUri",
    "verification_token": "verificationToken",
    "version_header_name": "versionHeaderName",
    "version_query_name": "versionQueryName",
    "version_set_id": "versionSetId",
    "versioning_scheme": "versioningScheme",
    "virtual_hub_id": "virtualHubId",
    "virtual_ip": "virtualIp",
    "virtual_machine_id": "virtualMachineId",
    "virtual_machine_name": "virtualMachineName",
    "virtual_network_gateway_id": "virtualNetworkGatewayId",
    "virtual_network_id": "virtualNetworkId",
    "virtual_network_ids": "virtualNetworkIds",
    "virtual_network_name": "virtualNetworkName",
    "virtual_network_rules": "virtualNetworkRules",
    "virtual_network_subnet_ids": "virtualNetworkSubnetIds",
    "virtual_wan_id": "virtualWanId",
    "visibility_subscription_ids": "visibilitySubscriptionIds",
    "vlan_id": "vlanId",
    "vm_image": "vmImage",
    "vm_size": "vmSize",
    "vnet_integration": "vnetIntegration",
    "vnet_subnet_id": "vnetSubnetId",
    "voice_receivers": "voiceReceivers",
    "vpn_authentication_types": "vpnAuthenticationTypes",
    "vpn_client_configuration": "vpnClientConfiguration",
    "vpn_protocols": "vpnProtocols",
    "vpn_server_configuration_id": "vpnServerConfigurationId",
    "vpn_type": "vpnType",
    "vsts_configuration": "vstsConfiguration",
    "waf_configuration": "wafConfiguration",
    "webhook_action": "webhookAction",
    "webhook_endpoint": "webhookEndpoint",
    "webhook_receivers": "webhookReceivers",
    "week_days": "weekDays",
    "weekly_recurrence": "weeklyRecurrence",
    "window_size": "windowSize",
    "windows_profile": "windowsProfile",
    "workflow_schema": "workflowSchema",
    "workflow_version": "workflowVersion",
    "workspace_id": "workspaceId",
    "workspace_name": "workspaceName",
    "workspace_resource_id": "workspaceResourceId",
    "write_accelerator_enabled": "writeAcceleratorEnabled",
    "write_endpoints": "writeEndpoints",
    "write_permissions": "writePermissions",
    "x_ms_client_id": "xMsClientId",
    "xml_content": "xmlContent",
    "xml_link": "xmlLink",
    "zone_name": "zoneName",
    "zone_redundant": "zoneRedundant",
    "zone_resilient": "zoneResilient",
    "zone_type": "zoneType",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessEndpoint": "access_endpoint",
    "accessPolicies": "access_policies",
    "accessPolicyObjectIds": "access_policy_object_ids",
    "accessTier": "access_tier",
    "accountEncryptionSource": "account_encryption_source",
    "accountEndpoint": "account_endpoint",
    "accountKind": "account_kind",
    "accountName": "account_name",
    "accountReplicationType": "account_replication_type",
    "accountTier": "account_tier",
    "accountType": "account_type",
    "actionStorageQueue": "action_storage_queue",
    "actionWeb": "action_web",
    "activeActive": "active_active",
    "activeDirectory": "active_directory",
    "addOnFeatures": "add_on_features",
    "additionalCapabilities": "additional_capabilities",
    "additionalLocations": "additional_locations",
    "additionalProperties": "additional_properties",
    "addonProfile": "addon_profile",
    "addressPrefix": "address_prefix",
    "addressSpaces": "address_spaces",
    "adminEnabled": "admin_enabled",
    "adminPassword": "admin_password",
    "adminUsername": "admin_username",
    "adminUsers": "admin_users",
    "administratorLogin": "administrator_login",
    "administratorLoginPassword": "administrator_login_password",
    "agentPoolProfile": "agent_pool_profile",
    "agentPoolProfiles": "agent_pool_profiles",
    "alertNotifications": "alert_notifications",
    "alertsToAdmins": "alerts_to_admins",
    "allocatedOutboundPorts": "allocated_outbound_ports",
    "allocationMethod": "allocation_method",
    "allocationPolicy": "allocation_policy",
    "allowBranchToBranchTraffic": "allow_branch_to_branch_traffic",
    "allowClaim": "allow_claim",
    "allowClassicOperations": "allow_classic_operations",
    "allowForwardedTraffic": "allow_forwarded_traffic",
    "allowGatewayTransit": "allow_gateway_transit",
    "allowUpdates": "allow_updates",
    "allowVirtualNetworkAccess": "allow_virtual_network_access",
    "allowVnetToVnetTraffic": "allow_vnet_to_vnet_traffic",
    "alternateName": "alternate_name",
    "apiKey": "api_key",
    "apiManagementName": "api_management_name",
    "apiName": "api_name",
    "apiServerAuthorizedIpRanges": "api_server_authorized_ip_ranges",
    "apnsCredential": "apns_credential",
    "appId": "app_id",
    "appServiceCertificateNotRenewableReasons": "app_service_certificate_not_renewable_reasons",
    "appServiceEnvironmentId": "app_service_environment_id",
    "appServiceName": "app_service_name",
    "appServicePlanId": "app_service_plan_id",
    "appServiceSlotName": "app_service_slot_name",
    "appSettings": "app_settings",
    "applicationConsistentSnapshotFrequencyInMinutes": "application_consistent_snapshot_frequency_in_minutes",
    "applicationId": "application_id",
    "applicationInsights": "application_insights",
    "applicationInsightsId": "application_insights_id",
    "applicationSecurityGroupId": "application_security_group_id",
    "applicationType": "application_type",
    "appliedDnsServers": "applied_dns_servers",
    "approvalRequired": "approval_required",
    "armRoleReceivers": "arm_role_receivers",
    "artifactsStorageAccountId": "artifacts_storage_account_id",
    "assignableScopes": "assignable_scopes",
    "authSettings": "auth_settings",
    "authenticationCertificates": "authentication_certificates",
    "authenticationConfiguration": "authentication_configuration",
    "authorizationEndpoint": "authorization_endpoint",
    "authorizationKey": "authorization_key",
    "authorizationMethods": "authorization_methods",
    "authorizationUseStatus": "authorization_use_status",
    "autoApprovalSubscriptionIds": "auto_approval_subscription_ids",
    "autoDeleteOnIdle": "auto_delete_on_idle",
    "autoInflateEnabled": "auto_inflate_enabled",
    "autoMitigate": "auto_mitigate",
    "autoRenew": "auto_renew",
    "autoScale": "auto_scale",
    "autoStart": "auto_start",
    "autoUpgradeMinorVersion": "auto_upgrade_minor_version",
    "automaticOsUpgrade": "automatic_os_upgrade",
    "automationAccountName": "automation_account_name",
    "automationRunbookReceivers": "automation_runbook_receivers",
    "autoscaleConfiguration": "autoscale_configuration",
    "auxiliaryTenantIds": "auxiliary_tenant_ids",
    "availabilitySetId": "availability_set_id",
    "availabilityZones": "availability_zones",
    "availableToOtherTenants": "available_to_other_tenants",
    "azureActiveDirectory": "azure_active_directory",
    "azureActiveDirectoryAuthentications": "azure_active_directory_authentications",
    "azureAppPushReceivers": "azure_app_push_receivers",
    "azureAsn": "azure_asn",
    "azureFirewallName": "azure_firewall_name",
    "azureFunctionReceivers": "azure_function_receivers",
    "backendAddressPoolId": "backend_address_pool_id",
    "backendAddressPools": "backend_address_pools",
    "backendHttpSettings": "backend_http_settings",
    "backendIpConfigurationId": "backend_ip_configuration_id",
    "backendIpConfigurations": "backend_ip_configurations",
    "backendPoolHealthProbes": "backend_pool_health_probes",
    "backendPoolLoadBalancings": "backend_pool_load_balancings",
    "backendPools": "backend_pools",
    "backendPort": "backend_port",
    "backupBlobContainerUri": "backup_blob_container_uri",
    "backupPolicyId": "backup_policy_id",
    "bandwidthInMbps": "bandwidth_in_mbps",
    "batchFrequencyInSeconds": "batch_frequency_in_seconds",
    "bearerTokenSendingMethods": "bearer_token_sending_methods",
    "bgpSettings": "bgp_settings",
    "bootDiagnostics": "boot_diagnostics",
    "botName": "bot_name",
    "captureDescription": "capture_description",
    "catalogInfo": "catalog_info",
    "certificateCommonNames": "certificate_common_names",
    "certificateContent": "certificate_content",
    "certificateData": "certificate_data",
    "certificatePermissions": "certificate_permissions",
    "certificatePolicy": "certificate_policy",
    "clientAffinityEnabled": "client_affinity_enabled",
    "clientAuthenticationMethods": "client_authentication_methods",
    "clientCertEnabled": "client_cert_enabled",
    "clientCertificatePassword": "client_certificate_password",
    "clientCertificatePath": "client_certificate_path",
    "clientCertificateThumbprints": "client_certificate_thumbprints",
    "clientId": "client_id",
    "clientRegistrationEndpoint": "client_registration_endpoint",
    "clientRevokedCertificates": "client_revoked_certificates",
    "clientRootCertificates": "client_root_certificates",
    "clientSecret": "client_secret",
    "clusterCodeVersion": "cluster_code_version",
    "clusterEndpoint": "cluster_endpoint",
    "clusterName": "cluster_name",
    "clusterVersion": "cluster_version",
    "compatibilityLevel": "compatibility_level",
    "componentVersion": "component_version",
    "configurationName": "configuration_name",
    "connectionConfiguration": "connection_configuration",
    "connectionString": "connection_string",
    "connectionStrings": "connection_strings",
    "consistencyPolicy": "consistency_policy",
    "consumerGroup": "consumer_group",
    "containerAccessType": "container_access_type",
    "containerConfiguration": "container_configuration",
    "containerName": "container_name",
    "containerNetworkInterface": "container_network_interface",
    "containerNetworkInterfaceIds": "container_network_interface_ids",
    "contentEmbedded": "content_embedded",
    "contentType": "content_type",
    "contentTypesToCompresses": "content_types_to_compresses",
    "correlationFilter": "correlation_filter",
    "corsConfiguration": "cors_configuration",
    "cosmosdbThroughput": "cosmosdb_throughput",
    "createMode": "create_mode",
    "createOption": "create_option",
    "creationDate": "creation_date",
    "customBlockResponseBody": "custom_block_response_body",
    "customBlockResponseStatusCode": "custom_block_response_status_code",
    "customDomain": "custom_domain",
    "customErrorConfigurations": "custom_error_configurations",
    "customHeaders": "custom_headers",
    "customRules": "custom_rules",
    "customSetupScript": "custom_setup_script",
    "dailyRecurrence": "daily_recurrence",
    "dashboardProperties": "dashboard_properties",
    "dataDisks": "data_disks",
    "dataFactoryName": "data_factory_name",
    "dataFormat": "data_format",
    "dataIngestionUri": "data_ingestion_uri",
    "dataLocale": "data_locale",
    "dataPlaneFqdn": "data_plane_fqdn",
    "databaseName": "database_name",
    "dateFormat": "date_format",
    "dbDtuMax": "db_dtu_max",
    "dbDtuMin": "db_dtu_min",
    "ddosProtectionPlan": "ddos_protection_plan",
    "deadLetteringOnFilterEvaluationExceptions": "dead_lettering_on_filter_evaluation_exceptions",
    "deadLetteringOnMessageExpiration": "dead_lettering_on_message_expiration",
    "defaultAction": "default_action",
    "defaultHostname": "default_hostname",
    "defaultLocalNetworkGatewayId": "default_local_network_gateway_id",
    "defaultMessageTtl": "default_message_ttl",
    "defaultNodePool": "default_node_pool",
    "defaultPremiumStorageAccountId": "default_premium_storage_account_id",
    "defaultPrimaryConnectionString": "default_primary_connection_string",
    "defaultPrimaryKey": "default_primary_key",
    "defaultScope": "default_scope",
    "defaultSecondaryConnectionString": "default_secondary_connection_string",
    "defaultSecondaryKey": "default_secondary_key",
    "defaultSecondaryLocation": "default_secondary_location",
    "defaultSiteHostname": "default_site_hostname",
    "defaultStorageAccountId": "default_storage_account_id",
    "defaultStoreAccountName": "default_store_account_name",
    "defaultTtlSeconds": "default_ttl_seconds",
    "defaultVersion": "default_version",
    "deleteDataDisksOnTermination": "delete_data_disks_on_termination",
    "deleteOsDiskOnTermination": "delete_os_disk_on_termination",
    "deploymentMode": "deployment_mode",
    "destinationAddressPrefix": "destination_address_prefix",
    "destinationAddressPrefixes": "destination_address_prefixes",
    "destinationApplicationSecurityGroupIds": "destination_application_security_group_ids",
    "destinationPortRange": "destination_port_range",
    "destinationPortRanges": "destination_port_ranges",
    "developerAppInsightsApiKey": "developer_app_insights_api_key",
    "developerAppInsightsApplicationId": "developer_app_insights_application_id",
    "developerAppInsightsKey": "developer_app_insights_key",
    "deviceConnect": "device_connect",
    "deviceProvisioningHostName": "device_provisioning_host_name",
    "diagnosticsConfig": "diagnostics_config",
    "diagnosticsProfile": "diagnostics_profile",
    "disableBgpRoutePropagation": "disable_bgp_route_propagation",
    "disableCorrelationRequestId": "disable_correlation_request_id",
    "disableOutboundSnat": "disable_outbound_snat",
    "disableTerraformPartnerId": "disable_terraform_partner_id",
    "disableVpnEncryption": "disable_vpn_encryption",
    "disabledSslProtocols": "disabled_ssl_protocols",
    "disallowPublicIpAddress": "disallow_public_ip_address",
    "diskIopsReadWrite": "disk_iops_read_write",
    "diskMbpsReadWrite": "disk_mbps_read_write",
    "diskSizeGb": "disk_size_gb",
    "displayName": "display_name",
    "distinguishedName": "distinguished_name",
    "dnsConfigs": "dns_configs",
    "dnsName": "dns_name",
    "dnsNameLabel": "dns_name_label",
    "dnsPrefix": "dns_prefix",
    "dnsServers": "dns_servers",
    "domainNameLabel": "domain_name_label",
    "domainVerificationToken": "domain_verification_token",
    "dscPrimaryAccessKey": "dsc_primary_access_key",
    "dscSecondaryAccessKey": "dsc_secondary_access_key",
    "dscServerEndpoint": "dsc_server_endpoint",
    "duplicateDetectionHistoryTimeWindow": "duplicate_detection_history_time_window",
    "edgeSshEndpoint": "edge_ssh_endpoint",
    "elasticPoolName": "elastic_pool_name",
    "elasticPoolProperties": "elastic_pool_properties",
    "emailAction": "email_action",
    "emailAddress": "email_address",
    "emailPassword": "email_password",
    "emailReceivers": "email_receivers",
    "enableAcceleratedNetworking": "enable_accelerated_networking",
    "enableAdvancedThreatProtection": "enable_advanced_threat_protection",
    "enableAutoScaling": "enable_auto_scaling",
    "enableAutomaticFailover": "enable_automatic_failover",
    "enableBatchedOperations": "enable_batched_operations",
    "enableBgp": "enable_bgp",
    "enableBlobEncryption": "enable_blob_encryption",
    "enableBuiltinLogging": "enable_builtin_logging",
    "enableExpress": "enable_express",
    "enableFileEncryption": "enable_file_encryption",
    "enableFilteringMessagesBeforePublishing": "enable_filtering_messages_before_publishing",
    "enableFloatingIp": "enable_floating_ip",
    "enableHttp2": "enable_http2",
    "enableHttpsTrafficOnly": "enable_https_traffic_only",
    "enableIpForwarding": "enable_ip_forwarding",
    "enableMultipleWriteLocations": "enable_multiple_write_locations",
    "enableNodePublicIp": "enable_node_public_ip",
    "enableNonSslPort": "enable_non_ssl_port",
    "enablePartitioning": "enable_partitioning",
    "enablePodSecurityPolicy": "enable_pod_security_policy",
    "enablePowerBiService": "enable_power_bi_service",
    "enableTcpReset": "enable_tcp_reset",
    "enabledForDeployment": "enabled_for_deployment",
    "enabledForDiskEncryption": "enabled_for_disk_encryption",
    "enabledForTemplateDeployment": "enabled_for_template_deployment",
    "encryptionSettings": "encryption_settings",
    "encryptionState": "encryption_state",
    "encryptionType": "encryption_type",
    "endDate": "end_date",
    "endIp": "end_ip",
    "endIpAddress": "end_ip_address",
    "endTime": "end_time",
    "endpointLocation": "endpoint_location",
    "endpointMonitorStatus": "endpoint_monitor_status",
    "endpointNames": "endpoint_names",
    "endpointStatus": "endpoint_status",
    "enforceBackendPoolsCertificateNameCheck": "enforce_backend_pools_certificate_name_check",
    "enforcePrivateLinkEndpointNetworkPolicies": "enforce_private_link_endpoint_network_policies",
    "enforcePrivateLinkServiceNetworkPolicies": "enforce_private_link_service_network_policies",
    "errorActionStorageQueue": "error_action_storage_queue",
    "errorActionWeb": "error_action_web",
    "evaluatorType": "evaluator_type",
    "eventDeliverySchema": "event_delivery_schema",
    "eventHubEventsEndpoint": "event_hub_events_endpoint",
    "eventHubEventsPath": "event_hub_events_path",
    "eventHubOperationsEndpoint": "event_hub_operations_endpoint",
    "eventHubOperationsPath": "event_hub_operations_path",
    "eventhubAuthorizationRuleId": "eventhub_authorization_rule_id",
    "eventhubConsumerGroupName": "eventhub_consumer_group_name",
    "eventhubEndpoint": "eventhub_endpoint",
    "eventhubEndpointName": "eventhub_endpoint_name",
    "eventhubId": "eventhub_id",
    "eventhubName": "eventhub_name",
    "eventsLateArrivalMaxDelayInSeconds": "events_late_arrival_max_delay_in_seconds",
    "eventsOutOfOrderMaxDelayInSeconds": "events_out_of_order_max_delay_in_seconds",
    "eventsOutOfOrderPolicy": "events_out_of_order_policy",
    "evictionPolicy": "eviction_policy",
    "excludeFromLatest": "exclude_from_latest",
    "expirationDate": "expiration_date",
    "expirationTime": "expiration_time",
    "expiryTime": "expiry_time",
    "expressRouteCircuitId": "express_route_circuit_id",
    "expressRouteCircuitName": "express_route_circuit_name",
    "expressRouteGatewayBypass": "express_route_gateway_bypass",
    "externalId": "external_id",
    "fabricSettings": "fabric_settings",
    "factData": "fact_data",
    "failoverPolicies": "failover_policies",
    "fallbackRoute": "fallback_route",
    "fileNameFormat": "file_name_format",
    "fileUpload": "file_upload",
    "filterType": "filter_type",
    "firewallAllowAzureIps": "firewall_allow_azure_ips",
    "firewallState": "firewall_state",
    "firstName": "first_name",
    "fixedScale": "fixed_scale",
    "forwardDeadLetteredMessagesTo": "forward_dead_lettered_messages_to",
    "forwardTo": "forward_to",
    "friendlyName": "friendly_name",
    "frontendEndpointIds": "frontend_endpoint_ids",
    "frontendEndpoints": "frontend_endpoints",
    "frontendIpConfigurationId": "frontend_ip_configuration_id",
    "frontendIpConfigurationName": "frontend_ip_configuration_name",
    "frontendIpConfigurations": "frontend_ip_configurations",
    "frontendPort": "frontend_port",
    "frontendPortEnd": "frontend_port_end",
    "frontendPortStart": "frontend_port_start",
    "frontendPorts": "frontend_ports",
    "fullyQualifiedDomainName": "fully_qualified_domain_name",
    "functionAlias": "function_alias",
    "galleryImageReference": "gallery_image_reference",
    "galleryName": "gallery_name",
    "gatewayAddress": "gateway_address",
    "gatewayIpConfigurations": "gateway_ip_configurations",
    "gatewayRegionalUrl": "gateway_regional_url",
    "gatewayUrl": "gateway_url",
    "gcmCredential": "gcm_credential",
    "geoFilters": "geo_filters",
    "geoLocations": "geo_locations",
    "geoMappings": "geo_mappings",
    "georeplicationLocations": "georeplication_locations",
    "githubConfiguration": "github_configuration",
    "grantTypes": "grant_types",
    "groupId": "group_id",
    "groupName": "group_name",
    "hasImmutabilityPolicy": "has_immutability_policy",
    "hasLegalHold": "has_legal_hold",
    "healthProbeId": "health_probe_id",
    "hostName": "host_name",
    "hostNames": "host_names",
    "hostSuffix": "host_suffix",
    "hostnameConfiguration": "hostname_configuration",
    "hotCachePeriod": "hot_cache_period",
    "hourlyRecurrence": "hourly_recurrence",
    "httpListeners": "http_listeners",
    "httpsEndpoint": "https_endpoint",
    "httpsOnly": "https_only",
    "hybridConnectionEndpoint": "hybrid_connection_endpoint",
    "idScope": "id_scope",
    "identifierUris": "identifier_uris",
    "idleTimeoutInMinutes": "idle_timeout_in_minutes",
    "ignoreMissingVnetServiceEndpoint": "ignore_missing_vnet_service_endpoint",
    "imageName": "image_name",
    "imageReferenceId": "image_reference_id",
    "imageRegistryCredentials": "image_registry_credentials",
    "import": "import_",
    "inboundNatRules": "inbound_nat_rules",
    "includedEventTypes": "included_event_types",
    "inputMappingDefaultValues": "input_mapping_default_values",
    "inputMappingFields": "input_mapping_fields",
    "inputSchema": "input_schema",
    "instrumentationKey": "instrumentation_key",
    "integrationRuntimeName": "integration_runtime_name",
    "intermediateThumbprint": "intermediate_thumbprint",
    "internalDnsNameLabel": "internal_dns_name_label",
    "internalFqdn": "internal_fqdn",
    "intervalInSeconds": "interval_in_seconds",
    "iotDpsName": "iot_dps_name",
    "iothubName": "iothub_name",
    "iothubNamespace": "iothub_namespace",
    "ipAddress": "ip_address",
    "ipAddressType": "ip_address_type",
    "ipConfiguration": "ip_configuration",
    "ipConfigurationName": "ip_configuration_name",
    "ipConfigurations": "ip_configurations",
    "ipFilterRules": "ip_filter_rules",
    "ipPrefix": "ip_prefix",
    "ipRangeFilter": "ip_range_filter",
    "ipRules": "ip_rules",
    "ipVersion": "ip_version",
    "ipsecPolicy": "ipsec_policy",
    "ipv4FirewallRules": "ipv4_firewall_rules",
    "isCompressionEnabled": "is_compression_enabled",
    "isCurrent": "is_current",
    "isHnsEnabled": "is_hns_enabled",
    "isHttpAllowed": "is_http_allowed",
    "isHttpsAllowed": "is_https_allowed",
    "isOnline": "is_online",
    "isPrivateKeyExternal": "is_private_key_external",
    "isVirtualNetworkFilterEnabled": "is_virtual_network_filter_enabled",
    "isXenon": "is_xenon",
    "issueDate": "issue_date",
    "itsmReceivers": "itsm_receivers",
    "jobCollectionName": "job_collection_name",
    "jobId": "job_id",
    "jobScheduleId": "job_schedule_id",
    "kafkaEnabled": "kafka_enabled",
    "keyId": "key_id",
    "keyOpts": "key_opts",
    "keyPermissions": "key_permissions",
    "keySize": "key_size",
    "keyType": "key_type",
    "keyVaultId": "key_vault_id",
    "keyVaultReference": "key_vault_reference",
    "keyVaultSecretId": "key_vault_secret_id",
    "kubeAdminConfig": "kube_admin_config",
    "kubeAdminConfigRaw": "kube_admin_config_raw",
    "kubeConfig": "kube_config",
    "kubeConfigRaw": "kube_config_raw",
    "kubernetesClusterId": "kubernetes_cluster_id",
    "kubernetesVersion": "kubernetes_version",
    "labName": "lab_name",
    "labSubnetName": "lab_subnet_name",
    "labVirtualNetworkId": "lab_virtual_network_id",
    "landingPageUrl": "landing_page_url",
    "lastName": "last_name",
    "licenseTextLink": "license_text_link",
    "licenseType": "license_type",
    "linkedHubs": "linked_hubs",
    "linkedServiceName": "linked_service_name",
    "linkedServiceProperties": "linked_service_properties",
    "linuxProfile": "linux_profile",
    "loadBalancerEnabled": "load_balancer_enabled",
    "loadBalancerFrontendIpConfigurationIds": "load_balancer_frontend_ip_configuration_ids",
    "loadBalancerRules": "load_balancer_rules",
    "loadBalancingRules": "load_balancing_rules",
    "loadDistribution": "load_distribution",
    "loadbalancerId": "loadbalancer_id",
    "localFilePath": "local_file_path",
    "localNetworkGatewayId": "local_network_gateway_id",
    "lockDuration": "lock_duration",
    "lockLevel": "lock_level",
    "logAnalyticsDestinationType": "log_analytics_destination_type",
    "logAnalyticsWorkspaceId": "log_analytics_workspace_id",
    "logProgress": "log_progress",
    "logVerbose": "log_verbose",
    "logicAppId": "logic_app_id",
    "logicAppReceivers": "logic_app_receivers",
    "loginServer": "login_server",
    "luisAppIds": "luis_app_ids",
    "luisKey": "luis_key",
    "macAddress": "mac_address",
    "managedDiskId": "managed_disk_id",
    "managedDisks": "managed_disks",
    "managedImageId": "managed_image_id",
    "managedResourceGroupId": "managed_resource_group_id",
    "managedResourceGroupName": "managed_resource_group_name",
    "managedRules": "managed_rules",
    "managementApiUrl": "management_api_url",
    "managementEndpoint": "management_endpoint",
    "managementGroupId": "management_group_id",
    "mappingRuleName": "mapping_rule_name",
    "masterProfile": "master_profile",
    "maxChunkSizeInBytes": "max_chunk_size_in_bytes",
    "maxCount": "max_count",
    "maxDeliveryCount": "max_delivery_count",
    "maxNumberOfRecordSets": "max_number_of_record_sets",
    "maxNumberOfVirtualNetworkLinks": "max_number_of_virtual_network_links",
    "maxNumberOfVirtualNetworkLinksWithRegistration": "max_number_of_virtual_network_links_with_registration",
    "maxParallelExecutionsPerNode": "max_parallel_executions_per_node",
    "maxPods": "max_pods",
    "maxSizeBytes": "max_size_bytes",
    "maxSizeGb": "max_size_gb",
    "maxSizeInMegabytes": "max_size_in_megabytes",
    "maxTasksPerNode": "max_tasks_per_node",
    "maximumBytesPerPacket": "maximum_bytes_per_packet",
    "maximumBytesPerSession": "maximum_bytes_per_session",
    "maximumCaptureDuration": "maximum_capture_duration",
    "maximumElasticWorkerCount": "maximum_elastic_worker_count",
    "maximumNumberOfWorkers": "maximum_number_of_workers",
    "maximumThroughputUnits": "maximum_throughput_units",
    "messageRetention": "message_retention",
    "metadataEndpoint": "metadata_endpoint",
    "metricId": "metric_id",
    "metricName": "metric_name",
    "microsoftAppId": "microsoft_app_id",
    "microsoftPeeringConfig": "microsoft_peering_config",
    "minChildEndpoints": "min_child_endpoints",
    "minCount": "min_count",
    "minimumTlsVersion": "minimum_tls_version",
    "moduleLink": "module_link",
    "monitorConfigs": "monitor_configs",
    "monthDays": "month_days",
    "monthlyOccurrences": "monthly_occurrences",
    "msiEndpoint": "msi_endpoint",
    "nameServers": "name_servers",
    "namespaceName": "namespace_name",
    "namespaceType": "namespace_type",
    "natGatewayId": "nat_gateway_id",
    "natIpConfigurations": "nat_ip_configurations",
    "natRuleId": "nat_rule_id",
    "networkAcls": "network_acls",
    "networkInterfaceId": "network_interface_id",
    "networkInterfaceIds": "network_interface_ids",
    "networkProfile": "network_profile",
    "networkProfileId": "network_profile_id",
    "networkProfiles": "network_profiles",
    "networkRuleSet": "network_rule_set",
    "networkRules": "network_rules",
    "networkRulesets": "network_rulesets",
    "networkSecurityGroupId": "network_security_group_id",
    "networkSecurityGroupName": "network_security_group_name",
    "networkWatcherName": "network_watcher_name",
    "nextHopInIpAddress": "next_hop_in_ip_address",
    "nextHopType": "next_hop_type",
    "nodeAgentSkuId": "node_agent_sku_id",
    "nodeCount": "node_count",
    "nodeResourceGroup": "node_resource_group",
    "nodeSize": "node_size",
    "nodeTaints": "node_taints",
    "nodeTypes": "node_types",
    "notBeforeDate": "not_before_date",
    "notScopes": "not_scopes",
    "notificationHubName": "notification_hub_name",
    "notificationSenderEmail": "notification_sender_email",
    "notificationSettings": "notification_settings",
    "numberOfNodes": "number_of_nodes",
    "numberOfProbes": "number_of_probes",
    "numberOfRecordSets": "number_of_record_sets",
    "oauth2AllowImplicitFlow": "oauth2_allow_implicit_flow",
    "objectId": "object_id",
    "offerType": "offer_type",
    "office365LocalBreakoutCategory": "office365_local_breakout_category",
    "operationId": "operation_id",
    "optimizationType": "optimization_type",
    "orchestrationPlatform": "orchestration_platform",
    "originHostHeader": "origin_host_header",
    "originPath": "origin_path",
    "osDisk": "os_disk",
    "osDiskSizeGb": "os_disk_size_gb",
    "osProfile": "os_profile",
    "osProfileLinuxConfig": "os_profile_linux_config",
    "osProfileSecrets": "os_profile_secrets",
    "osProfileWindowsConfig": "os_profile_windows_config",
    "osType": "os_type",
    "outboundIpAddresses": "outbound_ip_addresses",
    "outputErrorPolicy": "output_error_policy",
    "parametersBody": "parameters_body",
    "parentManagementGroupId": "parent_management_group_id",
    "partitionCount": "partition_count",
    "partitionIds": "partition_ids",
    "partitionKey": "partition_key",
    "partitionKeyPath": "partition_key_path",
    "partnerId": "partner_id",
    "partnerNamespaceId": "partner_namespace_id",
    "partnerServers": "partner_servers",
    "patchSchedules": "patch_schedules",
    "pathPattern": "path_pattern",
    "peerAsn": "peer_asn",
    "peerVirtualNetworkGatewayId": "peer_virtual_network_gateway_id",
    "peeringLocation": "peering_location",
    "peeringType": "peering_type",
    "perDatabaseSettings": "per_database_settings",
    "perSiteScaling": "per_site_scaling",
    "pfxBlob": "pfx_blob",
    "pipelineName": "pipeline_name",
    "pipelineParameters": "pipeline_parameters",
    "platformFaultDomainCount": "platform_fault_domain_count",
    "platformUpdateDomainCount": "platform_update_domain_count",
    "policyDefinitionId": "policy_definition_id",
    "policyDefinitions": "policy_definitions",
    "policyRule": "policy_rule",
    "policySetName": "policy_set_name",
    "policySettings": "policy_settings",
    "policyType": "policy_type",
    "poolAllocationMode": "pool_allocation_mode",
    "poolSize": "pool_size",
    "portalUrl": "portal_url",
    "possibleOutboundIpAddresses": "possible_outbound_ip_addresses",
    "prefixLength": "prefix_length",
    "premiumDataDiskStorageAccountId": "premium_data_disk_storage_account_id",
    "primaryAccessKey": "primary_access_key",
    "primaryAzurePort": "primary_azure_port",
    "primaryBlobConnectionString": "primary_blob_connection_string",
    "primaryBlobEndpoint": "primary_blob_endpoint",
    "primaryBlobHost": "primary_blob_host",
    "primaryConnectionString": "primary_connection_string",
    "primaryDfsEndpoint": "primary_dfs_endpoint",
    "primaryDfsHost": "primary_dfs_host",
    "primaryFileEndpoint": "primary_file_endpoint",
    "primaryFileHost": "primary_file_host",
    "primaryKey": "primary_key",
    "primaryLocation": "primary_location",
    "primaryMasterKey": "primary_master_key",
    "primaryNetworkInterfaceId": "primary_network_interface_id",
    "primaryPeerAddressPrefix": "primary_peer_address_prefix",
    "primaryQueueEndpoint": "primary_queue_endpoint",
    "primaryQueueHost": "primary_queue_host",
    "primaryReadonlyMasterKey": "primary_readonly_master_key",
    "primarySharedKey": "primary_shared_key",
    "primaryTableEndpoint": "primary_table_endpoint",
    "primaryTableHost": "primary_table_host",
    "primaryWebEndpoint": "primary_web_endpoint",
    "primaryWebHost": "primary_web_host",
    "principalId": "principal_id",
    "principalType": "principal_type",
    "privacyPolicyLink": "privacy_policy_link",
    "privacyStatementUri": "privacy_statement_uri",
    "privateDnsZoneName": "private_dns_zone_name",
    "privateIpAddress": "private_ip_address",
    "privateIpAddresses": "private_ip_addresses",
    "privateServiceConnection": "private_service_connection",
    "privateStaticIpAddress": "private_static_ip_address",
    "probeId": "probe_id",
    "probePath": "probe_path",
    "productId": "product_id",
    "productType": "product_type",
    "profileName": "profile_name",
    "profileStatus": "profile_status",
    "protectedSettings": "protected_settings",
    "proximityPlacementGroupId": "proximity_placement_group_id",
    "publicData": "public_data",
    "publicIpAddressAllocation": "public_ip_address_allocation",
    "publicIpAddressIds": "public_ip_address_ids",
    "publicIpAddresses": "public_ip_addresses",
    "publicIpPrefixId": "public_ip_prefix_id",
    "publicIpPrefixIds": "public_ip_prefix_ids",
    "publicPort": "public_port",
    "publishContentLink": "publish_content_link",
    "publisherEmail": "publisher_email",
    "publisherName": "publisher_name",
    "querypoolConnectionMode": "querypool_connection_mode",
    "querystringCachingBehaviour": "querystring_caching_behaviour",
    "queueName": "queue_name",
    "queueProperties": "queue_properties",
    "radiusServer": "radius_server",
    "readEndpoints": "read_endpoints",
    "readPermissions": "read_permissions",
    "readScale": "read_scale",
    "readWriteEndpointFailoverPolicy": "read_write_endpoint_failover_policy",
    "readonlyEndpointFailoverPolicy": "readonly_endpoint_failover_policy",
    "recoveryFabricName": "recovery_fabric_name",
    "recoveryPointRetentionInMinutes": "recovery_point_retention_in_minutes",
    "recoveryReplicationPolicyId": "recovery_replication_policy_id",
    "recoverySourceProtectionContainerName": "recovery_source_protection_container_name",
    "recoveryTargetProtectionContainerId": "recovery_target_protection_container_id",
    "recoveryVaultName": "recovery_vault_name",
    "redirectConfigurations": "redirect_configurations",
    "redirectUrl": "redirect_url",
    "redisCacheName": "redis_cache_name",
    "redisConfiguration": "redis_configuration",
    "registrationEnabled": "registration_enabled",
    "registrationVirtualNetworkIds": "registration_virtual_network_ids",
    "registryName": "registry_name",
    "registryRead": "registry_read",
    "registryWrite": "registry_write",
    "relativePath": "relative_path",
    "relayNamespaceName": "relay_namespace_name",
    "releaseNoteUri": "release_note_uri",
    "reliabilityLevel": "reliability_level",
    "remoteFilePath": "remote_file_path",
    "remoteVirtualNetworkId": "remote_virtual_network_id",
    "replicaCount": "replica_count",
    "replyUrls": "reply_urls",
    "requestPath": "request_path",
    "requestRoutingRules": "request_routing_rules",
    "requestedServiceObjectiveId": "requested_service_objective_id",
    "requestedServiceObjectiveName": "requested_service_objective_name",
    "requiresClientAuthorization": "requires_client_authorization",
    "requiresDuplicateDetection": "requires_duplicate_detection",
    "requiresSession": "requires_session",
    "resolutionVirtualNetworkIds": "resolution_virtual_network_ids",
    "resourceGroupName": "resource_group_name",
    "resourceGuid": "resource_guid",
    "resourceId": "resource_id",
    "resourceOwnerPassword": "resource_owner_password",
    "resourceOwnerUsername": "resource_owner_username",
    "restartPolicy": "restart_policy",
    "restorePointInTime": "restore_point_in_time",
    "retentionDaily": "retention_daily",
    "retentionInDays": "retention_in_days",
    "retentionMonthly": "retention_monthly",
    "retentionPolicy": "retention_policy",
    "retentionWeekly": "retention_weekly",
    "retentionYearly": "retention_yearly",
    "retryEnabled": "retry_enabled",
    "retryPolicy": "retry_policy",
    "reverseFqdn": "reverse_fqdn",
    "reverseProxyCertificate": "reverse_proxy_certificate",
    "rewriteRuleSets": "rewrite_rule_sets",
    "roleBasedAccessControl": "role_based_access_control",
    "roleDefinitionId": "role_definition_id",
    "roleDefinitionName": "role_definition_name",
    "rollingUpgradePolicy": "rolling_upgrade_policy",
    "rootThumbprint": "root_thumbprint",
    "routeTableId": "route_table_id",
    "routeTableName": "route_table_name",
    "routingRules": "routing_rules",
    "routingWeight": "routing_weight",
    "rowKey": "row_key",
    "runOn": "run_on",
    "runbookName": "runbook_name",
    "runbookType": "runbook_type",
    "samplingPercentage": "sampling_percentage",
    "scaleUnit": "scale_unit",
    "scheduleName": "schedule_name",
    "schemaColumns": "schema_columns",
    "schemaId": "schema_id",
    "scmUrl": "scm_url",
    "secondaryAccessKey": "secondary_access_key",
    "secondaryAzurePort": "secondary_azure_port",
    "secondaryBlobConnectionString": "secondary_blob_connection_string",
    "secondaryBlobEndpoint": "secondary_blob_endpoint",
    "secondaryBlobHost": "secondary_blob_host",
    "secondaryConnectionString": "secondary_connection_string",
    "secondaryDfsEndpoint": "secondary_dfs_endpoint",
    "secondaryDfsHost": "secondary_dfs_host",
    "secondaryFileEndpoint": "secondary_file_endpoint",
    "secondaryFileHost": "secondary_file_host",
    "secondaryKey": "secondary_key",
    "secondaryLocation": "secondary_location",
    "secondaryMasterKey": "secondary_master_key",
    "secondaryPeerAddressPrefix": "secondary_peer_address_prefix",
    "secondaryQueueEndpoint": "secondary_queue_endpoint",
    "secondaryQueueHost": "secondary_queue_host",
    "secondaryReadonlyMasterKey": "secondary_readonly_master_key",
    "secondarySharedKey": "secondary_shared_key",
    "secondaryTableEndpoint": "secondary_table_endpoint",
    "secondaryTableHost": "secondary_table_host",
    "secondaryWebEndpoint": "secondary_web_endpoint",
    "secondaryWebHost": "secondary_web_host",
    "secretId": "secret_id",
    "secretPermissions": "secret_permissions",
    "securityProviderName": "security_provider_name",
    "securityRules": "security_rules",
    "serverFullName": "server_full_name",
    "serverName": "server_name",
    "serverPort": "server_port",
    "serviceConnect": "service_connect",
    "serviceEndpoints": "service_endpoints",
    "serviceFabricCluster": "service_fabric_cluster",
    "serviceKey": "service_key",
    "serviceLevel": "service_level",
    "serviceOperationsHostName": "service_operations_host_name",
    "servicePrincipal": "service_principal",
    "servicePrincipalId": "service_principal_id",
    "servicePrincipalKey": "service_principal_key",
    "serviceProviderName": "service_provider_name",
    "serviceProviderProvisioningState": "service_provider_provisioning_state",
    "serviceUri": "service_uri",
    "serviceUrl": "service_url",
    "servicebusEndpoint": "servicebus_endpoint",
    "servicebusNamespace": "servicebus_namespace",
    "servicebusRuleId": "servicebus_rule_id",
    "shardCount": "shard_count",
    "shardKey": "shard_key",
    "shareName": "share_name",
    "sharedAccessPolicies": "shared_access_policies",
    "sharedAccessPolicyKey": "shared_access_policy_key",
    "sharedAccessPolicyName": "shared_access_policy_name",
    "sharedKey": "shared_key",
    "shortName": "short_name",
    "signIn": "sign_in",
    "signUp": "sign_up",
    "signedCertificateThumbprint": "signed_certificate_thumbprint",
    "singlePlacementGroup": "single_placement_group",
    "siteConfig": "site_config",
    "siteCredential": "site_credential",
    "sizeInTb": "size_in_tb",
    "skipCredentialsValidation": "skip_credentials_validation",
    "skipProviderRegistration": "skip_provider_registration",
    "skipServicePrincipalAadCheck": "skip_service_principal_aad_check",
    "skuName": "sku_name",
    "smsReceivers": "sms_receivers",
    "soapPassThrough": "soap_pass_through",
    "softDeletePeriod": "soft_delete_period",
    "solutionName": "solution_name",
    "sourceAddressPrefix": "source_address_prefix",
    "sourceAddressPrefixes": "source_address_prefixes",
    "sourceApplicationSecurityGroupIds": "source_application_security_group_ids",
    "sourceContent": "source_content",
    "sourceControl": "source_control",
    "sourceDatabaseDeletionDate": "source_database_deletion_date",
    "sourceDatabaseId": "source_database_id",
    "sourceNetworkId": "source_network_id",
    "sourcePortRange": "source_port_range",
    "sourcePortRanges": "source_port_ranges",
    "sourceRecoveryFabricName": "source_recovery_fabric_name",
    "sourceRecoveryProtectionContainerName": "source_recovery_protection_container_name",
    "sourceResourceId": "source_resource_id",
    "sourceUri": "source_uri",
    "sourceVirtualMachineId": "source_virtual_machine_id",
    "sourceVmId": "source_vm_id",
    "sqlFilter": "sql_filter",
    "sshEndpoint": "ssh_endpoint",
    "sshKey": "ssh_key",
    "sslCertificates": "ssl_certificates",
    "sslEnforcement": "ssl_enforcement",
    "sslPolicies": "ssl_policies",
    "sslPort": "ssl_port",
    "sslState": "ssl_state",
    "startDate": "start_date",
    "startIp": "start_ip",
    "startIpAddress": "start_ip_address",
    "startTask": "start_task",
    "startTime": "start_time",
    "stopPendingResizeOperation": "stop_pending_resize_operation",
    "storageAccount": "storage_account",
    "storageAccountGen2": "storage_account_gen2",
    "storageAccountId": "storage_account_id",
    "storageAccountKey": "storage_account_key",
    "storageAccountName": "storage_account_name",
    "storageAccountType": "storage_account_type",
    "storageAccounts": "storage_accounts",
    "storageBlobDeadLetterDestination": "storage_blob_dead_letter_destination",
    "storageConnectionString": "storage_connection_string",
    "storageContainerName": "storage_container_name",
    "storageDataDisks": "storage_data_disks",
    "storageImageReference": "storage_image_reference",
    "storageLocation": "storage_location",
    "storageOsDisk": "storage_os_disk",
    "storagePermissions": "storage_permissions",
    "storageProfile": "storage_profile",
    "storageProfileDataDisks": "storage_profile_data_disks",
    "storageProfileImageReference": "storage_profile_image_reference",
    "storageProfileOsDisk": "storage_profile_os_disk",
    "storageQueueEndpoint": "storage_queue_endpoint",
    "storageType": "storage_type",
    "streamAnalyticsJobName": "stream_analytics_job_name",
    "streamingUnits": "streaming_units",
    "subjectFilter": "subject_filter",
    "subjectName": "subject_name",
    "subnetId": "subnet_id",
    "subscriptionId": "subscription_id",
    "subscriptionIds": "subscription_ids",
    "subscriptionKeyParameterNames": "subscription_key_parameter_names",
    "subscriptionName": "subscription_name",
    "subscriptionRequired": "subscription_required",
    "subscriptionsLimit": "subscriptions_limit",
    "supportOrdering": "support_ordering",
    "supportState": "support_state",
    "syntheticMonitorId": "synthetic_monitor_id",
    "tableName": "table_name",
    "targetAvailabilitySetId": "target_availability_set_id",
    "targetContainerHostCredentialsBase64": "target_container_host_credentials_base64",
    "targetContainerHostResourceId": "target_container_host_resource_id",
    "targetNetworkId": "target_network_id",
    "targetRecoveryFabricId": "target_recovery_fabric_id",
    "targetRecoveryFabricName": "target_recovery_fabric_name",
    "targetRecoveryProtectionContainerId": "target_recovery_protection_container_id",
    "targetRegions": "target_regions",
    "targetResourceGroupId": "target_resource_group_id",
    "targetResourceId": "target_resource_id",
    "taskType": "task_type",
    "templateBody": "template_body",
    "templateParameters": "template_parameters",
    "tenantId": "tenant_id",
    "threatDetectionPolicy": "threat_detection_policy",
    "thumbprintAlgorithm": "thumbprint_algorithm",
    "timeCreated": "time_created",
    "timeFormat": "time_format",
    "timeModified": "time_modified",
    "timeZoneId": "time_zone_id",
    "tokenBodyParameters": "token_body_parameters",
    "tokenEndpoint": "token_endpoint",
    "tokenSecret": "token_secret",
    "topicName": "topic_name",
    "trafficRoutingMethod": "traffic_routing_method",
    "transformationQuery": "transformation_query",
    "trustedRootCertificates": "trusted_root_certificates",
    "typeHandlerVersion": "type_handler_version",
    "uniqueIdentifier": "unique_identifier",
    "uniqueKeys": "unique_keys",
    "uniqueName": "unique_name",
    "upgradeMode": "upgrade_mode",
    "upgradePolicyMode": "upgrade_policy_mode",
    "urlPathMaps": "url_path_maps",
    "urlTemplate": "url_template",
    "useMsi": "use_msi",
    "usePolicyBasedTrafficSelectors": "use_policy_based_traffic_selectors",
    "useRemoteGateways": "use_remote_gateways",
    "userId": "user_id",
    "userMetadata": "user_metadata",
    "validityInYears": "validity_in_years",
    "vaultName": "vault_name",
    "vaultUri": "vault_uri",
    "verificationToken": "verification_token",
    "versionHeaderName": "version_header_name",
    "versionQueryName": "version_query_name",
    "versionSetId": "version_set_id",
    "versioningScheme": "versioning_scheme",
    "virtualHubId": "virtual_hub_id",
    "virtualIp": "virtual_ip",
    "virtualMachineId": "virtual_machine_id",
    "virtualMachineName": "virtual_machine_name",
    "virtualNetworkGatewayId": "virtual_network_gateway_id",
    "virtualNetworkId": "virtual_network_id",
    "virtualNetworkIds": "virtual_network_ids",
    "virtualNetworkName": "virtual_network_name",
    "virtualNetworkRules": "virtual_network_rules",
    "virtualNetworkSubnetIds": "virtual_network_subnet_ids",
    "virtualWanId": "virtual_wan_id",
    "visibilitySubscriptionIds": "visibility_subscription_ids",
    "vlanId": "vlan_id",
    "vmImage": "vm_image",
    "vmSize": "vm_size",
    "vnetIntegration": "vnet_integration",
    "vnetSubnetId": "vnet_subnet_id",
    "voiceReceivers": "voice_receivers",
    "vpnAuthenticationTypes": "vpn_authentication_types",
    "vpnClientConfiguration": "vpn_client_configuration",
    "vpnProtocols": "vpn_protocols",
    "vpnServerConfigurationId": "vpn_server_configuration_id",
    "vpnType": "vpn_type",
    "vstsConfiguration": "vsts_configuration",
    "wafConfiguration": "waf_configuration",
    "webhookAction": "webhook_action",
    "webhookEndpoint": "webhook_endpoint",
    "webhookReceivers": "webhook_receivers",
    "weekDays": "week_days",
    "weeklyRecurrence": "weekly_recurrence",
    "windowSize": "window_size",
    "windowsProfile": "windows_profile",
    "workflowSchema": "workflow_schema",
    "workflowVersion": "workflow_version",
    "workspaceId": "workspace_id",
    "workspaceName": "workspace_name",
    "workspaceResourceId": "workspace_resource_id",
    "writeAcceleratorEnabled": "write_accelerator_enabled",
    "writeEndpoints": "write_endpoints",
    "writePermissions": "write_permissions",
    "xMsClientId": "x_ms_client_id",
    "xmlContent": "xml_content",
    "xmlLink": "xml_link",
    "zoneName": "zone_name",
    "zoneRedundant": "zone_redundant",
    "zoneResilient": "zone_resilient",
    "zoneType": "zone_type",
}



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class LinkEndpoint(pulumi.CustomResource):
    location: pulumi.Output[str]
    """
    The supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    Specifies the Name of the Private Service Connection. Changing this forces a new resource to be created.
    """
    private_service_connection: pulumi.Output[dict]
    """
    A `private_service_connection` block as defined below.
    
      * `isManualConnection` (`bool`) - Does the Private Link Endpoint require Manual Approval from the remote resource owner? Changing this forces a new resource to be created.
      * `name` (`str`) - Specifies the Name of the Private Service Connection. Changing this forces a new resource to be created.
      * `privateConnectionResourceId` (`str`) - The ID of the Private Link Enabled Remote Resource which this Private Link Endpoint should be connected to. Changing this forces a new resource to be created.
      * `requestMessage` (`str`) - A message passed to the owner of the remote resource when the private link endpoint attempts to establish the connection to the remote resource. The request message can be a maximum of `140` characters in length. Only valid if `is_manual_connection` is set to `true`.
      * `subresourceNames` (`list`) - A list of subresource names which the Private Link Endpoint is able to connect to. Changing this forces a new resource to be created.
    """
    resource_group_name: pulumi.Output[str]
    """
    Specifies the Name of the Resource Group within which the Private Link Endpoint should exist. Changing this forces a new resource to be created.
    """
    subnet_id: pulumi.Output[str]
    """
    The ID of the Subnet from which Private IP Addresses will be allocated for this Private Link Endpoint. Changing this forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, location=None, name=None, private_service_connection=None, resource_group_name=None, subnet_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an Endpoint within a Private Link Service.
        
        > **NOTE** Private Link is currently in Public Preview.
        
        Azure Private Link Endpoint is a network interface that connects you privately and securely to a service powered by Azure Private Link. Private Link Endpoint uses a private IP address from your VNet, effectively bringing the service into your VNet. The service could be an Azure service such as Azure Storage, SQL, etc. or your own Private Link Service.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: The supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the Name of the Private Service Connection. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] private_service_connection: A `private_service_connection` block as defined below.
        :param pulumi.Input[str] resource_group_name: Specifies the Name of the Resource Group within which the Private Link Endpoint should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] subnet_id: The ID of the Subnet from which Private IP Addresses will be allocated for this Private Link Endpoint. Changing this forces a new resource to be created.
        
        The **private_service_connection** object supports the following:
        
          * `isManualConnection` (`pulumi.Input[bool]`) - Does the Private Link Endpoint require Manual Approval from the remote resource owner? Changing this forces a new resource to be created.
          * `name` (`pulumi.Input[str]`) - Specifies the Name of the Private Service Connection. Changing this forces a new resource to be created.
          * `privateConnectionResourceId` (`pulumi.Input[str]`) - The ID of the Private Link Enabled Remote Resource which this Private Link Endpoint should be connected to. Changing this forces a new resource to be created.
          * `requestMessage` (`pulumi.Input[str]`) - A message passed to the owner of the remote resource when the private link endpoint attempts to establish the connection to the remote resource. The request message can be a maximum of `140` characters in length. Only valid if `is_manual_connection` is set to `true`.
          * `subresourceNames` (`pulumi.Input[list]`) - A list of subresource names which the Private Link Endpoint is able to connect to. Changing this forces a new resource to be created.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/private_link_endpoint.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['location'] = location
            __props__['name'] = name
            if private_service_connection is None:
                raise TypeError("Missing required property 'private_service_connection'")
            __props__['private_service_connection'] = private_service_connection
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if subnet_id is None:
                raise TypeError("Missing required property 'subnet_id'")
            __props__['subnet_id'] = subnet_id
        super(LinkEndpoint, __self__).__init__(
            'azure:privatedns/linkEndpoint:LinkEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, location=None, name=None, private_service_connection=None, resource_group_name=None, subnet_id=None):
        """
        Get an existing LinkEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: The supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the Name of the Private Service Connection. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] private_service_connection: A `private_service_connection` block as defined below.
        :param pulumi.Input[str] resource_group_name: Specifies the Name of the Resource Group within which the Private Link Endpoint should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] subnet_id: The ID of the Subnet from which Private IP Addresses will be allocated for this Private Link Endpoint. Changing this forces a new resource to be created.
        
        The **private_service_connection** object supports the following:
        
          * `isManualConnection` (`pulumi.Input[bool]`) - Does the Private Link Endpoint require Manual Approval from the remote resource owner? Changing this forces a new resource to be created.
          * `name` (`pulumi.Input[str]`) - Specifies the Name of the Private Service Connection. Changing this forces a new resource to be created.
          * `privateConnectionResourceId` (`pulumi.Input[str]`) - The ID of the Private Link Enabled Remote Resource which this Private Link Endpoint should be connected to. Changing this forces a new resource to be created.
          * `requestMessage` (`pulumi.Input[str]`) - A message passed to the owner of the remote resource when the private link endpoint attempts to establish the connection to the remote resource. The request message can be a maximum of `140` characters in length. Only valid if `is_manual_connection` is set to `true`.
          * `subresourceNames` (`pulumi.Input[list]`) - A list of subresource names which the Private Link Endpoint is able to connect to. Changing this forces a new resource to be created.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/private_link_endpoint.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["location"] = location
        __props__["name"] = name
        __props__["private_service_connection"] = private_service_connection
        __props__["resource_group_name"] = resource_group_name
        __props__["subnet_id"] = subnet_id
        return LinkEndpoint(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import importlib
# Make subpackages available:
__all__ = ['ad', 'analysisservices', 'apimanagement', 'appinsights', 'appservice', 'authorization', 'automation', 'autoscale', 'batch', 'bot', 'cdn', 'cognitive', 'compute', 'config', 'containerservice', 'core', 'cosmosdb', 'dashboard', 'databricks', 'datafactory', 'datalake', 'ddosprotection', 'devspace', 'devtest', 'dns', 'eventgrid', 'eventhub', 'frontdoor', 'hdinsight', 'healthcare', 'iot', 'keyvault', 'kusto', 'lb', 'loganalytics', 'logicapps', 'management', 'managementgroups', 'managementresource', 'maps', 'mariadb', 'marketplace', 'mediaservices', 'monitoring', 'msi', 'mssql', 'mysql', 'netapp', 'network', 'notificationhub', 'operationalinsights', 'policy', 'postgresql', 'privatedns', 'privatelink', 'proximity', 'recoveryservices', 'redis', 'relay', 'role', 'scheduler', 'search', 'securitycenter', 'servicebus', 'servicefabric', 'signalr', 'sql', 'storage', 'streamanalytics', 'trafficmanager', 'waf']
for pkg in __all__:
    if pkg != 'config':
        importlib.import_module(f'{__name__}.{pkg}')

# Export this package's modules as members:
from .provider import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Frontdoor(pulumi.CustomResource):
    backend_pools: pulumi.Output[list]
    """
    A `backend_pool` block as defined below.
    
      * `backends` (`list`)
    
        * `address` (`str`)
        * `enabled` (`bool`)
        * `hostHeader` (`str`)
        * `httpPort` (`float`)
        * `httpsPort` (`float`)
        * `priority` (`float`)
        * `weight` (`float`)
    
      * `healthProbeName` (`str`)
      * `id` (`str`) - Resource ID.
      * `loadBalancingName` (`str`)
      * `name` (`str`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
    """
    backend_pool_health_probes: pulumi.Output[list]
    """
    A `backend_pool_health_probe` block as defined below.
    
      * `id` (`str`) - Resource ID.
      * `intervalInSeconds` (`float`)
      * `name` (`str`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
      * `path` (`str`)
      * `protocol` (`str`)
    """
    backend_pool_load_balancings: pulumi.Output[list]
    """
    A `backend_pool_load_balancing` block as defined below.
    
      * `additionalLatencyMilliseconds` (`float`)
      * `id` (`str`) - Resource ID.
      * `name` (`str`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
      * `sampleSize` (`float`)
      * `successfulSamplesRequired` (`float`)
    """
    cname: pulumi.Output[str]
    """
    The host that each frontendEndpoint must CNAME to.
    """
    enforce_backend_pools_certificate_name_check: pulumi.Output[bool]
    """
    Whether to enforce certificate name check on HTTPS requests to all backend pools. No effect on non-HTTPS requests. Permitted values are `true` or `false`.
    """
    friendly_name: pulumi.Output[str]
    """
    A friendly name for the Front Door service.
    """
    frontend_endpoints: pulumi.Output[list]
    """
    A `frontend_endpoint` block as defined below.
    
      * `customHttpsConfiguration` (`dict`)
    
        * `azureKeyVaultCertificateSecretName` (`str`)
        * `azureKeyVaultCertificateSecretVersion` (`str`)
        * `azureKeyVaultCertificateVaultId` (`str`)
        * `certificateSource` (`str`)
        * `provisioningState` (`str`) - Provisioning state of the Front Door.
        * `provisioningSubstate` (`str`) - Provisioning substate of the Front Door
    
      * `customHttpsProvisioningEnabled` (`bool`)
      * `host_name` (`str`)
      * `id` (`str`) - Resource ID.
      * `name` (`str`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
      * `sessionAffinityEnabled` (`bool`)
      * `sessionAffinityTtlSeconds` (`float`)
      * `webApplicationFirewallPolicyLinkId` (`str`) - (Optional) The `id` of the `web_application_firewall_policy_link` to use for this Frontend Endpoint."
    """
    load_balancer_enabled: pulumi.Output[bool]
    """
    Operational status of the Front Door load balancer. Permitted values are `true` or `false` Defaults to `true`.
    """
    location: pulumi.Output[str]
    """
    Resource location. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
    """
    resource_group_name: pulumi.Output[str]
    """
    Name of the Resource group within the Azure subscription. Changing this forces a new resource to be created.
    """
    routing_rules: pulumi.Output[list]
    """
    A `routing_rule` block as defined below.
    
      * `acceptedProtocols` (`list`)
      * `enabled` (`bool`)
      * `forwardingConfiguration` (`dict`)
    
        * `backendPoolName` (`str`)
        * `cacheQueryParameterStripDirective` (`str`)
        * `cacheUseDynamicCompression` (`bool`)
        * `customForwardingPath` (`str`)
        * `forwardingProtocol` (`str`)
    
      * `frontend_endpoints` (`list`)
      * `id` (`str`) - Resource ID.
      * `name` (`str`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
      * `patternsToMatches` (`list`)
      * `redirectConfiguration` (`dict`)
    
        * `customFragment` (`str`)
        * `customHost` (`str`)
        * `customPath` (`str`)
        * `customQueryString` (`str`)
        * `redirectProtocol` (`str`)
        * `redirectType` (`str`)
    """
    tags: pulumi.Output[dict]
    """
    Resource tags.
    """
    def __init__(__self__, resource_name, opts=None, backend_pools=None, backend_pool_health_probes=None, backend_pool_load_balancings=None, enforce_backend_pools_certificate_name_check=None, friendly_name=None, frontend_endpoints=None, load_balancer_enabled=None, location=None, name=None, resource_group_name=None, routing_rules=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an Azure Front Door instance.
        
        Azure Front Door Service is Microsoft's highly available and scalable web application acceleration platform and global HTTP(s) load balancer. It provides built-in DDoS protection and application layer security and caching. Front Door enables you to build applications that maximize and automate high-availability and performance for your end-users. Use Front Door with Azure services including Web/Mobile Apps, Cloud Services and Virtual Machines – or combine it with on-premises services for hybrid deployments and smooth cloud migration.
        
        Below are some of the key scenarios that Azure Front Door Service addresses: 
        * Use Front Door to improve application scale and availability with instant multi-region failover
        * Use Front Door to improve application performance with SSL offload and routing requests to the fastest available application backend.
        * Use Front Door for application layer security and DDoS protection for your application.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] backend_pools: A `backend_pool` block as defined below.
        :param pulumi.Input[list] backend_pool_health_probes: A `backend_pool_health_probe` block as defined below.
        :param pulumi.Input[list] backend_pool_load_balancings: A `backend_pool_load_balancing` block as defined below.
        :param pulumi.Input[bool] enforce_backend_pools_certificate_name_check: Whether to enforce certificate name check on HTTPS requests to all backend pools. No effect on non-HTTPS requests. Permitted values are `true` or `false`.
        :param pulumi.Input[str] friendly_name: A friendly name for the Front Door service.
        :param pulumi.Input[list] frontend_endpoints: A `frontend_endpoint` block as defined below.
        :param pulumi.Input[bool] load_balancer_enabled: Operational status of the Front Door load balancer. Permitted values are `true` or `false` Defaults to `true`.
        :param pulumi.Input[str] location: Resource location. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: Name of the Resource group within the Azure subscription. Changing this forces a new resource to be created.
        :param pulumi.Input[list] routing_rules: A `routing_rule` block as defined below.
        :param pulumi.Input[dict] tags: Resource tags.
        
        The **backend_pool_health_probes** object supports the following:
        
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `intervalInSeconds` (`pulumi.Input[float]`)
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
          * `path` (`pulumi.Input[str]`)
          * `protocol` (`pulumi.Input[str]`)
        
        The **backend_pool_load_balancings** object supports the following:
        
          * `additionalLatencyMilliseconds` (`pulumi.Input[float]`)
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
          * `sampleSize` (`pulumi.Input[float]`)
          * `successfulSamplesRequired` (`pulumi.Input[float]`)
        
        The **backend_pools** object supports the following:
        
          * `backends` (`pulumi.Input[list]`)
        
            * `address` (`pulumi.Input[str]`)
            * `enabled` (`pulumi.Input[bool]`)
            * `hostHeader` (`pulumi.Input[str]`)
            * `httpPort` (`pulumi.Input[float]`)
            * `httpsPort` (`pulumi.Input[float]`)
            * `priority` (`pulumi.Input[float]`)
            * `weight` (`pulumi.Input[float]`)
        
          * `healthProbeName` (`pulumi.Input[str]`)
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `loadBalancingName` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
        
        The **frontend_endpoints** object supports the following:
        
          * `customHttpsConfiguration` (`pulumi.Input[dict]`)
        
            * `azureKeyVaultCertificateSecretName` (`pulumi.Input[str]`)
            * `azureKeyVaultCertificateSecretVersion` (`pulumi.Input[str]`)
            * `azureKeyVaultCertificateVaultId` (`pulumi.Input[str]`)
            * `certificateSource` (`pulumi.Input[str]`)
            * `provisioningState` (`pulumi.Input[str]`) - Provisioning state of the Front Door.
            * `provisioningSubstate` (`pulumi.Input[str]`) - Provisioning substate of the Front Door
        
          * `customHttpsProvisioningEnabled` (`pulumi.Input[bool]`)
          * `host_name` (`pulumi.Input[str]`)
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
          * `sessionAffinityEnabled` (`pulumi.Input[bool]`)
          * `sessionAffinityTtlSeconds` (`pulumi.Input[float]`)
          * `webApplicationFirewallPolicyLinkId` (`pulumi.Input[str]`) - (Optional) The `id` of the `web_application_firewall_policy_link` to use for this Frontend Endpoint."
        
        The **routing_rules** object supports the following:
        
          * `acceptedProtocols` (`pulumi.Input[list]`)
          * `enabled` (`pulumi.Input[bool]`)
          * `forwardingConfiguration` (`pulumi.Input[dict]`)
        
            * `backendPoolName` (`pulumi.Input[str]`)
            * `cacheQueryParameterStripDirective` (`pulumi.Input[str]`)
            * `cacheUseDynamicCompression` (`pulumi.Input[bool]`)
            * `customForwardingPath` (`pulumi.Input[str]`)
            * `forwardingProtocol` (`pulumi.Input[str]`)
        
          * `frontend_endpoints` (`pulumi.Input[list]`)
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
          * `patternsToMatches` (`pulumi.Input[list]`)
          * `redirectConfiguration` (`pulumi.Input[dict]`)
        
            * `customFragment` (`pulumi.Input[str]`)
            * `customHost` (`pulumi.Input[str]`)
            * `customPath` (`pulumi.Input[str]`)
            * `customQueryString` (`pulumi.Input[str]`)
            * `redirectProtocol` (`pulumi.Input[str]`)
            * `redirectType` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/frontdoor.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if backend_pools is None:
                raise TypeError("Missing required property 'backend_pools'")
            __props__['backend_pools'] = backend_pools
            if backend_pool_health_probes is None:
                raise TypeError("Missing required property 'backend_pool_health_probes'")
            __props__['backend_pool_health_probes'] = backend_pool_health_probes
            if backend_pool_load_balancings is None:
                raise TypeError("Missing required property 'backend_pool_load_balancings'")
            __props__['backend_pool_load_balancings'] = backend_pool_load_balancings
            if enforce_backend_pools_certificate_name_check is None:
                raise TypeError("Missing required property 'enforce_backend_pools_certificate_name_check'")
            __props__['enforce_backend_pools_certificate_name_check'] = enforce_backend_pools_certificate_name_check
            __props__['friendly_name'] = friendly_name
            if frontend_endpoints is None:
                raise TypeError("Missing required property 'frontend_endpoints'")
            __props__['frontend_endpoints'] = frontend_endpoints
            __props__['load_balancer_enabled'] = load_balancer_enabled
            __props__['location'] = location
            __props__['name'] = name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if routing_rules is None:
                raise TypeError("Missing required property 'routing_rules'")
            __props__['routing_rules'] = routing_rules
            __props__['tags'] = tags
            __props__['cname'] = None
        super(Frontdoor, __self__).__init__(
            'azure:frontdoor/frontdoor:Frontdoor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, backend_pools=None, backend_pool_health_probes=None, backend_pool_load_balancings=None, cname=None, enforce_backend_pools_certificate_name_check=None, friendly_name=None, frontend_endpoints=None, load_balancer_enabled=None, location=None, name=None, resource_group_name=None, routing_rules=None, tags=None):
        """
        Get an existing Frontdoor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] backend_pools: A `backend_pool` block as defined below.
        :param pulumi.Input[list] backend_pool_health_probes: A `backend_pool_health_probe` block as defined below.
        :param pulumi.Input[list] backend_pool_load_balancings: A `backend_pool_load_balancing` block as defined below.
        :param pulumi.Input[str] cname: The host that each frontendEndpoint must CNAME to.
        :param pulumi.Input[bool] enforce_backend_pools_certificate_name_check: Whether to enforce certificate name check on HTTPS requests to all backend pools. No effect on non-HTTPS requests. Permitted values are `true` or `false`.
        :param pulumi.Input[str] friendly_name: A friendly name for the Front Door service.
        :param pulumi.Input[list] frontend_endpoints: A `frontend_endpoint` block as defined below.
        :param pulumi.Input[bool] load_balancer_enabled: Operational status of the Front Door load balancer. Permitted values are `true` or `false` Defaults to `true`.
        :param pulumi.Input[str] location: Resource location. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: Name of the Resource group within the Azure subscription. Changing this forces a new resource to be created.
        :param pulumi.Input[list] routing_rules: A `routing_rule` block as defined below.
        :param pulumi.Input[dict] tags: Resource tags.
        
        The **backend_pool_health_probes** object supports the following:
        
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `intervalInSeconds` (`pulumi.Input[float]`)
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
          * `path` (`pulumi.Input[str]`)
          * `protocol` (`pulumi.Input[str]`)
        
        The **backend_pool_load_balancings** object supports the following:
        
          * `additionalLatencyMilliseconds` (`pulumi.Input[float]`)
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
          * `sampleSize` (`pulumi.Input[float]`)
          * `successfulSamplesRequired` (`pulumi.Input[float]`)
        
        The **backend_pools** object supports the following:
        
          * `backends` (`pulumi.Input[list]`)
        
            * `address` (`pulumi.Input[str]`)
            * `enabled` (`pulumi.Input[bool]`)
            * `hostHeader` (`pulumi.Input[str]`)
            * `httpPort` (`pulumi.Input[float]`)
            * `httpsPort` (`pulumi.Input[float]`)
            * `priority` (`pulumi.Input[float]`)
            * `weight` (`pulumi.Input[float]`)
        
          * `healthProbeName` (`pulumi.Input[str]`)
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `loadBalancingName` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
        
        The **frontend_endpoints** object supports the following:
        
          * `customHttpsConfiguration` (`pulumi.Input[dict]`)
        
            * `azureKeyVaultCertificateSecretName` (`pulumi.Input[str]`)
            * `azureKeyVaultCertificateSecretVersion` (`pulumi.Input[str]`)
            * `azureKeyVaultCertificateVaultId` (`pulumi.Input[str]`)
            * `certificateSource` (`pulumi.Input[str]`)
            * `provisioningState` (`pulumi.Input[str]`) - Provisioning state of the Front Door.
            * `provisioningSubstate` (`pulumi.Input[str]`) - Provisioning substate of the Front Door
        
          * `customHttpsProvisioningEnabled` (`pulumi.Input[bool]`)
          * `host_name` (`pulumi.Input[str]`)
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
          * `sessionAffinityEnabled` (`pulumi.Input[bool]`)
          * `sessionAffinityTtlSeconds` (`pulumi.Input[float]`)
          * `webApplicationFirewallPolicyLinkId` (`pulumi.Input[str]`) - (Optional) The `id` of the `web_application_firewall_policy_link` to use for this Frontend Endpoint."
        
        The **routing_rules** object supports the following:
        
          * `acceptedProtocols` (`pulumi.Input[list]`)
          * `enabled` (`pulumi.Input[bool]`)
          * `forwardingConfiguration` (`pulumi.Input[dict]`)
        
            * `backendPoolName` (`pulumi.Input[str]`)
            * `cacheQueryParameterStripDirective` (`pulumi.Input[str]`)
            * `cacheUseDynamicCompression` (`pulumi.Input[bool]`)
            * `customForwardingPath` (`pulumi.Input[str]`)
            * `forwardingProtocol` (`pulumi.Input[str]`)
        
          * `frontend_endpoints` (`pulumi.Input[list]`)
          * `id` (`pulumi.Input[str]`) - Resource ID.
          * `name` (`pulumi.Input[str]`) - Name of the Front Door which is globally unique. Changing this forces a new resource to be created.
          * `patternsToMatches` (`pulumi.Input[list]`)
          * `redirectConfiguration` (`pulumi.Input[dict]`)
        
            * `customFragment` (`pulumi.Input[str]`)
            * `customHost` (`pulumi.Input[str]`)
            * `customPath` (`pulumi.Input[str]`)
            * `customQueryString` (`pulumi.Input[str]`)
            * `redirectProtocol` (`pulumi.Input[str]`)
            * `redirectType` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/frontdoor.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["backend_pools"] = backend_pools
        __props__["backend_pool_health_probes"] = backend_pool_health_probes
        __props__["backend_pool_load_balancings"] = backend_pool_load_balancings
        __props__["cname"] = cname
        __props__["enforce_backend_pools_certificate_name_check"] = enforce_backend_pools_certificate_name_check
        __props__["friendly_name"] = friendly_name
        __props__["frontend_endpoints"] = frontend_endpoints
        __props__["load_balancer_enabled"] = load_balancer_enabled
        __props__["location"] = location
        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["routing_rules"] = routing_rules
        __props__["tags"] = tags
        return Frontdoor(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .hadoop_cluster import *
from .h_base_cluster import *
from .interactive_query_cluster import *
from .kafka_cluster import *
from .ml_services_cluster import *
from .r_server_cluster import *
from .spark_cluster import *
from .storm_cluster import *
from .get_cluster import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .group import *
from .registry import *
from .registry_webook import *
from .service import *
from .kubernetes_cluster import *
from .kubernetes_cluster_node_pool import *
from .get_registry import *
from .get_kubernetes_cluster import *
from .get_kubernetes_service_versions import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetApplicationResult:
    """
    A collection of values returned by getApplication.
    """
    def __init__(__self__, application_id=None, available_to_other_tenants=None, homepage=None, identifier_uris=None, name=None, oauth2_allow_implicit_flow=None, object_id=None, reply_urls=None, id=None):
        if application_id and not isinstance(application_id, str):
            raise TypeError("Expected argument 'application_id' to be a str")
        __self__.application_id = application_id
        """
        the Application ID of the Azure Active Directory Application.
        """
        if available_to_other_tenants and not isinstance(available_to_other_tenants, bool):
            raise TypeError("Expected argument 'available_to_other_tenants' to be a bool")
        __self__.available_to_other_tenants = available_to_other_tenants
        """
        Is this Azure AD Application available to other tenants?
        """
        if homepage and not isinstance(homepage, str):
            raise TypeError("Expected argument 'homepage' to be a str")
        __self__.homepage = homepage
        if identifier_uris and not isinstance(identifier_uris, list):
            raise TypeError("Expected argument 'identifier_uris' to be a list")
        __self__.identifier_uris = identifier_uris
        """
        A list of user-defined URI(s) that uniquely identify a Web application within it's Azure AD tenant, or within a verified custom domain if the application is multi-tenant.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if oauth2_allow_implicit_flow and not isinstance(oauth2_allow_implicit_flow, bool):
            raise TypeError("Expected argument 'oauth2_allow_implicit_flow' to be a bool")
        __self__.oauth2_allow_implicit_flow = oauth2_allow_implicit_flow
        """
        Does this Azure AD Application allow OAuth2.0 implicit flow tokens?
        """
        if object_id and not isinstance(object_id, str):
            raise TypeError("Expected argument 'object_id' to be a str")
        __self__.object_id = object_id
        """
        the Object ID of the Azure Active Directory Application.
        """
        if reply_urls and not isinstance(reply_urls, list):
            raise TypeError("Expected argument 'reply_urls' to be a list")
        __self__.reply_urls = reply_urls
        """
        A list of URLs that user tokens are sent to for sign in, or the redirect URIs that OAuth 2.0 authorization codes and access tokens are sent to.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetApplicationResult(GetApplicationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApplicationResult(
            application_id=self.application_id,
            available_to_other_tenants=self.available_to_other_tenants,
            homepage=self.homepage,
            identifier_uris=self.identifier_uris,
            name=self.name,
            oauth2_allow_implicit_flow=self.oauth2_allow_implicit_flow,
            object_id=self.object_id,
            reply_urls=self.reply_urls,
            id=self.id)

def get_application(name=None,object_id=None,opts=None):
    """
    Use this data source to access information about an existing resource.
    
    :param str name: Specifies the name of the Application within Azure Active Directory.
    :param str object_id: Specifies the Object ID of the Application within Azure Active Directory.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/d/azuread_application.html.markdown.
    """
    __args__ = dict()

    __args__['name'] = name
    __args__['objectId'] = object_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:ad/getApplication:getApplication', __args__, opts=opts).value

    return AwaitableGetApplicationResult(
        application_id=__ret__.get('applicationId'),
        available_to_other_tenants=__ret__.get('availableToOtherTenants'),
        homepage=__ret__.get('homepage'),
        identifier_uris=__ret__.get('identifierUris'),
        name=__ret__.get('name'),
        oauth2_allow_implicit_flow=__ret__.get('oauth2AllowImplicitFlow'),
        object_id=__ret__.get('objectId'),
        reply_urls=__ret__.get('replyUrls'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class FirewallPolicy(pulumi.CustomResource):
    custom_block_response_body: pulumi.Output[str]
    """
    If a `custom_rule` block's action type is `block`, this is the response body. The body must be specified in base64 encoding.
    """
    custom_block_response_status_code: pulumi.Output[float]
    """
    If a `custom_rule` block's action type is `block`, this is the response status code. Possible values are `200`, `403`, `405`, `406`, or `429`.
    """
    custom_rules: pulumi.Output[list]
    """
    One or more `custom_rule` blocks as defined below.
    
      * `action` (`str`)
      * `enabled` (`bool`) - Is the policy a enabled state or disabled state. Defaults to `true`.
      * `matchConditions` (`list`)
    
        * `matchValues` (`list`)
        * `matchVariable` (`str`)
        * `negationCondition` (`bool`)
        * `operator` (`str`)
        * `selector` (`str`)
        * `transforms` (`list`)
    
      * `name` (`str`) - The name of the policy. Changing this forces a new resource to be created.
      * `priority` (`float`)
      * `rateLimitDurationInMinutes` (`float`)
      * `rateLimitThreshold` (`float`)
      * `type` (`str`)
    """
    enabled: pulumi.Output[bool]
    """
    Is the policy a enabled state or disabled state. Defaults to `true`.
    """
    frontend_endpoint_ids: pulumi.Output[list]
    """
    the Frontend Endpoints associated with this Front Door Web Application Firewall policy.
    """
    location: pulumi.Output[str]
    """
    Resource location.
    """
    managed_rules: pulumi.Output[list]
    """
    One or more `managed_rule` blocks as defined below.
    
      * `overrides` (`list`)
    
        * `rules` (`list`)
    
          * `action` (`str`)
          * `enabled` (`bool`) - Is the policy a enabled state or disabled state. Defaults to `true`.
          * `ruleId` (`str`)
    
        * `ruleGroupName` (`str`)
    
      * `type` (`str`)
      * `version` (`str`)
    """
    mode: pulumi.Output[str]
    """
    The firewall policy mode. Possible values are `Detection`, `Prevention` and defaults to `Prevention`.
    """
    name: pulumi.Output[str]
    """
    The name of the policy. Changing this forces a new resource to be created.
    """
    redirect_url: pulumi.Output[str]
    """
    If action type is redirect, this field represents redirect URL for the client.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group. Changing this forces a new resource to be created.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the Web Application Firewall Policy.
    """
    def __init__(__self__, resource_name, opts=None, custom_block_response_body=None, custom_block_response_status_code=None, custom_rules=None, enabled=None, managed_rules=None, mode=None, name=None, redirect_url=None, resource_group_name=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an Azure Front Door Web Application Firewall Policy instance.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] custom_block_response_body: If a `custom_rule` block's action type is `block`, this is the response body. The body must be specified in base64 encoding.
        :param pulumi.Input[float] custom_block_response_status_code: If a `custom_rule` block's action type is `block`, this is the response status code. Possible values are `200`, `403`, `405`, `406`, or `429`.
        :param pulumi.Input[list] custom_rules: One or more `custom_rule` blocks as defined below.
        :param pulumi.Input[bool] enabled: Is the policy a enabled state or disabled state. Defaults to `true`.
        :param pulumi.Input[list] managed_rules: One or more `managed_rule` blocks as defined below.
        :param pulumi.Input[str] mode: The firewall policy mode. Possible values are `Detection`, `Prevention` and defaults to `Prevention`.
        :param pulumi.Input[str] name: The name of the policy. Changing this forces a new resource to be created.
        :param pulumi.Input[str] redirect_url: If action type is redirect, this field represents redirect URL for the client.
        :param pulumi.Input[str] resource_group_name: The name of the resource group. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the Web Application Firewall Policy.
        
        The **custom_rules** object supports the following:
        
          * `action` (`pulumi.Input[str]`)
          * `enabled` (`pulumi.Input[bool]`) - Is the policy a enabled state or disabled state. Defaults to `true`.
          * `matchConditions` (`pulumi.Input[list]`)
        
            * `matchValues` (`pulumi.Input[list]`)
            * `matchVariable` (`pulumi.Input[str]`)
            * `negationCondition` (`pulumi.Input[bool]`)
            * `operator` (`pulumi.Input[str]`)
            * `selector` (`pulumi.Input[str]`)
            * `transforms` (`pulumi.Input[list]`)
        
          * `name` (`pulumi.Input[str]`) - The name of the policy. Changing this forces a new resource to be created.
          * `priority` (`pulumi.Input[float]`)
          * `rateLimitDurationInMinutes` (`pulumi.Input[float]`)
          * `rateLimitThreshold` (`pulumi.Input[float]`)
          * `type` (`pulumi.Input[str]`)
        
        The **managed_rules** object supports the following:
        
          * `overrides` (`pulumi.Input[list]`)
        
            * `rules` (`pulumi.Input[list]`)
        
              * `action` (`pulumi.Input[str]`)
              * `enabled` (`pulumi.Input[bool]`) - Is the policy a enabled state or disabled state. Defaults to `true`.
              * `ruleId` (`pulumi.Input[str]`)
        
            * `ruleGroupName` (`pulumi.Input[str]`)
        
          * `type` (`pulumi.Input[str]`)
          * `version` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/frontdoor_firewall_policy.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['custom_block_response_body'] = custom_block_response_body
            __props__['custom_block_response_status_code'] = custom_block_response_status_code
            __props__['custom_rules'] = custom_rules
            __props__['enabled'] = enabled
            __props__['managed_rules'] = managed_rules
            __props__['mode'] = mode
            __props__['name'] = name
            __props__['redirect_url'] = redirect_url
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['tags'] = tags
            __props__['frontend_endpoint_ids'] = None
            __props__['location'] = None
        super(FirewallPolicy, __self__).__init__(
            'azure:frontdoor/firewallPolicy:FirewallPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, custom_block_response_body=None, custom_block_response_status_code=None, custom_rules=None, enabled=None, frontend_endpoint_ids=None, location=None, managed_rules=None, mode=None, name=None, redirect_url=None, resource_group_name=None, tags=None):
        """
        Get an existing FirewallPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] custom_block_response_body: If a `custom_rule` block's action type is `block`, this is the response body. The body must be specified in base64 encoding.
        :param pulumi.Input[float] custom_block_response_status_code: If a `custom_rule` block's action type is `block`, this is the response status code. Possible values are `200`, `403`, `405`, `406`, or `429`.
        :param pulumi.Input[list] custom_rules: One or more `custom_rule` blocks as defined below.
        :param pulumi.Input[bool] enabled: Is the policy a enabled state or disabled state. Defaults to `true`.
        :param pulumi.Input[list] frontend_endpoint_ids: the Frontend Endpoints associated with this Front Door Web Application Firewall policy.
        :param pulumi.Input[str] location: Resource location.
        :param pulumi.Input[list] managed_rules: One or more `managed_rule` blocks as defined below.
        :param pulumi.Input[str] mode: The firewall policy mode. Possible values are `Detection`, `Prevention` and defaults to `Prevention`.
        :param pulumi.Input[str] name: The name of the policy. Changing this forces a new resource to be created.
        :param pulumi.Input[str] redirect_url: If action type is redirect, this field represents redirect URL for the client.
        :param pulumi.Input[str] resource_group_name: The name of the resource group. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the Web Application Firewall Policy.
        
        The **custom_rules** object supports the following:
        
          * `action` (`pulumi.Input[str]`)
          * `enabled` (`pulumi.Input[bool]`) - Is the policy a enabled state or disabled state. Defaults to `true`.
          * `matchConditions` (`pulumi.Input[list]`)
        
            * `matchValues` (`pulumi.Input[list]`)
            * `matchVariable` (`pulumi.Input[str]`)
            * `negationCondition` (`pulumi.Input[bool]`)
            * `operator` (`pulumi.Input[str]`)
            * `selector` (`pulumi.Input[str]`)
            * `transforms` (`pulumi.Input[list]`)
        
          * `name` (`pulumi.Input[str]`) - The name of the policy. Changing this forces a new resource to be created.
          * `priority` (`pulumi.Input[float]`)
          * `rateLimitDurationInMinutes` (`pulumi.Input[float]`)
          * `rateLimitThreshold` (`pulumi.Input[float]`)
          * `type` (`pulumi.Input[str]`)
        
        The **managed_rules** object supports the following:
        
          * `overrides` (`pulumi.Input[list]`)
        
            * `rules` (`pulumi.Input[list]`)
        
              * `action` (`pulumi.Input[str]`)
              * `enabled` (`pulumi.Input[bool]`) - Is the policy a enabled state or disabled state. Defaults to `true`.
              * `ruleId` (`pulumi.Input[str]`)
        
            * `ruleGroupName` (`pulumi.Input[str]`)
        
          * `type` (`pulumi.Input[str]`)
          * `version` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/frontdoor_firewall_policy.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["custom_block_response_body"] = custom_block_response_body
        __props__["custom_block_response_status_code"] = custom_block_response_status_code
        __props__["custom_rules"] = custom_rules
        __props__["enabled"] = enabled
        __props__["frontend_endpoint_ids"] = frontend_endpoint_ids
        __props__["location"] = location
        __props__["managed_rules"] = managed_rules
        __props__["mode"] = mode
        __props__["name"] = name
        __props__["redirect_url"] = redirect_url
        __props__["resource_group_name"] = resource_group_name
        __props__["tags"] = tags
        return FirewallPolicy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

